@@ -1,8 +1,9 @@
 # Copyright 1999-2000 by Jeffrey Chang.  All rights reserved.
-# This code is part of the Biopython distribution and governed by its
-# license.  Please see the LICENSE file that should have been included
-# as part of this package.
-
+#
+# This file is part of the Biopython distribution and governed by your
+# choice of the "Biopython License Agreement" or the "BSD 3-Clause License".
+# Please see the LICENSE file that should have been included as part of this
+# package.
 """Record classes to hold BLAST output.
 
 Classes:
@@ -20,9 +21,12 @@ Parameters         Holds information from the parameters.
 """
 # XXX finish printable BLAST output
 
-from Bio.Align import Generic
+from Bio.Seq import Seq
+from Bio.SeqRecord import SeqRecord
+from Bio.Align import MultipleSeqAlignment
 
-class Header:
+
+class Header(object):
     """Saves information from a blast header.
 
     Members:
@@ -33,13 +37,15 @@ class Header:
 
     query               Name of query sequence.
     query_letters       Number of letters in the query sequence.  (int)
-    
+
     database            Name of the database.
     database_sequences  Number of sequences in the database.  (int)
     database_letters    Number of letters in the database.  (int)
 
     """
+
     def __init__(self):
+        """Initialize the class."""
         self.application = ''
         self.version = ''
         self.date = ''
@@ -52,7 +58,8 @@ class Header:
         self.database_sequences = None
         self.database_letters = None
 
-class Description:
+
+class Description(object):
     """Stores information about one hit in the descriptions section.
 
     Members:
@@ -61,18 +68,63 @@ class Description:
     bits            Bit score. (float)
     e               E value.  (float)
     num_alignments  Number of alignments for the same subject.  (int)
-    
     """
+
     def __init__(self):
+        """Initialize the class."""
         self.title = ''
         self.score = None
         self.bits = None
         self.e = None
         self.num_alignments = None
+
     def __str__(self):
+        """Return the description as a string."""
         return "%-66s %5s  %s" % (self.title, self.score, self.e)
 
-class Alignment:
+
+class DescriptionExt(Description):
+    """Extended description record for BLASTXML version 2.
+
+    Members:
+    items           List of DescriptionExtItem
+    """
+
+    def __init__(self):
+        """Initialize the class."""
+        super(DescriptionExt, self).__init__()
+
+        self.items = []
+
+    def append_item(self, item):
+        """Add a description extended record."""
+        if len(self.items) == 0:
+            self.title = str(item)
+        self.items.append(item)
+
+
+class DescriptionExtItem(object):
+    """Stores information about one record in hit description for BLASTXML version 2.
+
+    Members:
+    id              Database identifier
+    title           Title of the hit.
+    """
+
+    def __init__(self):
+        """Initialize the class."""
+        self.id = None
+        self.title = None
+        self.accession = None
+        self.taxid = None
+        self.sciname = None
+
+    def __str__(self):
+        """Return the description identifier and title as a string."""
+        return "%s %s" % (self.id, self.title)
+
+
+class Alignment(object):
     """Stores information about one hit in the alignments section.
 
     Members:
@@ -83,53 +135,59 @@ class Alignment:
     hsps       A list of HSP objects.
 
     """
+
     def __init__(self):
+        """Initialize the class."""
         self.title = ''
         self.hit_id = ''
         self.hit_def = ''
         self.length = None
         self.hsps = []
+
     def __str__(self):
+        """Return the BLAST alignment as a formatted string."""
         lines = self.title.split('\n')
         lines.append("Length = %s\n" % self.length)
         return '\n           '.join(lines)
 
-class HSP:
+
+class HSP(object):
     """Stores information about one hsp in an alignment hit.
 
     Members:
-    score           BLAST score of hit.  (float)
-    bits            Number of bits for that score.  (float)
-    expect          Expect value.  (float)
-    num_alignments  Number of alignments for same subject.  (int)
-    identities      Number of identities (int) if using the XML parser.
-                    Tuple of numer of identities/total aligned (int, int)
-                    if using the (obsolete) plain text parser.
-    positives       Number of positives (int) if using the XML parser.
-                    Tuple of numer of positives/total aligned (int, int)
-                    if using the (obsolete) plain text parser.
-    gaps            Number of gaps (int) if using the XML parser.
-                    Tuple of numer of gaps/total aligned (int, int) if
-                    using the (obsolete) plain text parser.
-    align_length    Length of the alignment. (int)
-    strand          Tuple of (query, target) strand.
-    frame           Tuple of 1 or 2 frame shifts, depending on the flavor.
+        - score           BLAST score of hit.  (float)
+        - bits            Number of bits for that score.  (float)
+        - expect          Expect value.  (float)
+        - num_alignments  Number of alignments for same subject.  (int)
+        - identities      Number of identities (int) if using the XML parser.
+          Tuple of number of identities/total aligned (int, int)
+          if using the (obsolete) plain text parser.
+        - positives       Number of positives (int) if using the XML parser.
+          Tuple of number of positives/total aligned (int, int)
+          if using the (obsolete) plain text parser.
+        - gaps            Number of gaps (int) if using the XML parser.
+          Tuple of number of gaps/total aligned (int, int) if
+          using the (obsolete) plain text parser.
+        - align_length    Length of the alignment. (int)
+        - strand          Tuple of (query, target) strand.
+        - frame           Tuple of 1 or 2 frame shifts, depending on the flavor.
 
-    query           The query sequence.
-    query_start     The start residue for the query sequence.  (1-based)
-    query_end       The end residue for the query sequence.  (1-based)
-    match           The match sequence.
-    sbjct           The sbjct sequence.
-    sbjct_start     The start residue for the sbjct sequence.  (1-based)
-    sbjct_end       The end residue for the sbjct sequence.  (1-based)
-    
-    Not all flavors of BLAST return values for every attribute:
-              score     expect     identities   positives    strand  frame
-    BLASTP     X          X            X            X
-    BLASTN     X          X            X            X          X
-    BLASTX     X          X            X            X                  X
-    TBLASTN    X          X            X            X                  X
-    TBLASTX    X          X            X            X                 X/X
+        - query           The query sequence.
+        - query_start     The start residue for the query sequence.  (1-based)
+        - query_end       The end residue for the query sequence.  (1-based)
+        - match           The match sequence.
+        - sbjct           The sbjct sequence.
+        - sbjct_start     The start residue for the sbjct sequence.  (1-based)
+        - sbjct_end       The end residue for the sbjct sequence.  (1-based)
+
+    Not all flavors of BLAST return values for every attribute::
+
+                  score     expect     identities   positives    strand  frame
+        BLASTP     X          X            X            X
+        BLASTN     X          X            X            X          X
+        BLASTX     X          X            X            X                  X
+        TBLASTN    X          X            X            X                  X
+        TBLASTX    X          X            X            X                 X/X
 
     Note: for BLASTX, the query sequence is shown as a protein sequence,
     but the numbering is based on the nucleotides.  Thus, the numbering
@@ -141,7 +199,9 @@ class HSP:
     query_start and counts down.
 
     """
+
     def __init__(self):
+        """Initialize the class."""
         self.score = None
         self.bits = None
         self.expect = None
@@ -152,7 +212,7 @@ class HSP:
         self.align_length = None
         self.strand = (None, None)
         self.frame = ()
-        
+
         self.query = ''
         self.query_start = None
         self.query_end = None
@@ -162,34 +222,36 @@ class HSP:
         self.sbjct_end = None
 
     def __str__(self):
-        lines = ["Score %i (%i bits), expectation %0.1e, alignment length %i" \
+        """Return the BLAST HSP as a formatted string."""
+        lines = ["Score %i (%i bits), expectation %0.1e, alignment length %i"
                  % (self.score, self.bits, self.expect, self.align_length)]
-        if self.align_length < 50 :
+        if self.align_length < 50:
             lines.append("Query:%s %s %s" % (str(self.query_start).rjust(8),
-                                       str(self.query),
-                                       str(self.query_end)))
-            lines.append("               %s" \
+                                             str(self.query),
+                                             str(self.query_end)))
+            lines.append("               %s"
                          % (str(self.match)))
             lines.append("Sbjct:%s %s %s" % (str(self.sbjct_start).rjust(8),
-                                       str(self.sbjct),
-                                       str(self.sbjct_end)))
-        else :
-            lines.append("Query:%s %s...%s %s" \
+                                             str(self.sbjct),
+                                             str(self.sbjct_end)))
+        else:
+            lines.append("Query:%s %s...%s %s"
                          % (str(self.query_start).rjust(8),
                             str(self.query)[:45],
                             str(self.query)[-3:],
                             str(self.query_end)))
-            lines.append("               %s...%s" \
+            lines.append("               %s...%s"
                          % (str(self.match)[:45],
                             str(self.match)[-3:]))
-            lines.append("Sbjct:%s %s...%s %s" \
+            lines.append("Sbjct:%s %s...%s %s"
                          % (str(self.sbjct_start).rjust(8),
                             str(self.sbjct)[:45],
                             str(self.sbjct)[-3:],
                             str(self.sbjct_end)))
         return "\n".join(lines)
 
-class MultipleAlignment:
+
+class MultipleAlignment(object):
     """Holds information about a multiple alignment.
 
     Members:
@@ -199,44 +261,48 @@ class MultipleAlignment:
     not aligned in the multiple alignment.
 
     """
+
     def __init__(self):
+        """Initialize the class."""
         self.alignment = []
 
     def to_generic(self, alphabet):
         """Retrieve generic alignment object for the given alignment.
 
-        Instead of the tuples, this returns an Alignment object from
-        Bio.Align.Generic, through which you can manipulate and query
+        Instead of the tuples, this returns a MultipleSeqAlignment object
+        from Bio.Align, through which you can manipulate and query
         the object.
 
         alphabet is the specified alphabet for the sequences in the code (for
-        example IUPAC.IUPACProtein.
+        example IUPAC.IUPACProtein).
 
         Thanks to James Casbon for the code.
         """
+        # TODO - Switch to new Bio.Align.MultipleSeqAlignment class?
         seq_parts = []
         seq_names = []
         parse_number = 0
         n = 0
         for name, start, seq, end in self.alignment:
-            if name == 'QUERY': #QUERY is the first in each alignment block
-                parse_number = parse_number + 1
+            if name == 'QUERY':  # QUERY is the first in each alignment block
+                parse_number += 1
                 n = 0
 
-            if parse_number == 1: # create on first_parse, append on all others
+            if parse_number == 1:  # create on first_parse, append on all others
                 seq_parts.append(seq)
                 seq_names.append(name)
             else:
-                seq_parts[n] = seq_parts[n] + seq
-                n = n + 1
+                seq_parts[n] += seq
+                n += 1
 
-        generic = Generic.Alignment(alphabet)
-        for (name,seq) in zip(seq_names,seq_parts):
-            generic.add_sequence(name, seq)
+        generic = MultipleSeqAlignment([], alphabet)
+        for (name, seq) in zip(seq_names, seq_parts):
+            generic.append(SeqRecord(Seq(seq, alphabet), name))
 
         return generic
 
-class Round:
+
+class Round(object):
     """Holds information from a PSI-BLAST round.
 
     Members:
@@ -245,18 +311,20 @@ class Round:
     new_seqs     Sequences not found, or below threshold.  List of Description.
     alignments          A list of Alignment objects.
     multiple_alignment  A MultipleAlignment object.
-    
     """
+
     def __init__(self):
+        """Initialize the class."""
         self.number = None
         self.reused_seqs = []
         self.new_seqs = []
         self.alignments = []
         self.multiple_alignment = None
 
-class DatabaseReport:
+
+class DatabaseReport(object):
     """Holds information about a database report.
-    
+
     Members:
     database_name              List of database names.  (can have multiple dbs)
     num_letters_in_database    Number of letters in the database.  (int)
@@ -267,7 +335,9 @@ class DatabaseReport:
     ka_params_gap              A tuple of (lambda, k, h) values.  (floats)
 
     """
+
     def __init__(self):
+        """Initialize the class."""
         self.database_name = []
         self.posted_date = []
         self.num_letters_in_database = []
@@ -276,7 +346,8 @@ class DatabaseReport:
         self.gapped = 0
         self.ka_params_gap = (None, None, None)
 
-class Parameters:
+
+class Parameters(object):
     """Holds information about the parameters.
 
     Members:
@@ -309,7 +380,9 @@ class Parameters:
     gap_trigger         Tuple of (score, bits).  (int, float)
     blast_cutoff        Tuple of (score, bits).  (int, float)
     """
+
     def __init__(self):
+        """Initialize the class."""
         self.matrix = ''
         self.gap_penalties = (None, None)
         self.sc_match = None
@@ -338,7 +411,9 @@ class Parameters:
         self.gap_x_dropoff_final = (None, None)
         self.gap_trigger = (None, None)
         self.blast_cutoff = (None, None)
-    
+
+
+# TODO - Add a friendly __str__ method to BLAST results
 class Blast(Header, DatabaseReport, Parameters):
     """Saves the results from a blast search.
 
@@ -349,7 +424,9 @@ class Blast(Header, DatabaseReport, Parameters):
     + members inherited from base classes
 
     """
+
     def __init__(self):
+        """Initialize the class."""
         Header.__init__(self)
         DatabaseReport.__init__(self)
         Parameters.__init__(self)
@@ -357,6 +434,7 @@ class Blast(Header, DatabaseReport, Parameters):
         self.alignments = []
         self.multiple_alignment = None
 
+
 class PSIBlast(Header, DatabaseReport, Parameters):
     """Saves the results from a blastpgp search.
 
@@ -366,7 +444,9 @@ class PSIBlast(Header, DatabaseReport, Parameters):
     + members inherited from base classes
 
     """
+
     def __init__(self):
+        """Initialize the class."""
         Header.__init__(self)
         DatabaseReport.__init__(self)
         Parameters.__init__(self)
