@@ -7,11 +7,12 @@
 
 Third-party libraries are loaded when the corresponding function is called.
 """
-__docformat__ = "restructuredtext en"
 
 import math
 import sys
 
+from Bio import MissingPythonDependencyError
+
 
 def to_networkx(tree):
     """Convert a Tree object to a networkx graph.
@@ -25,9 +26,8 @@ def to_networkx(tree):
     try:
         import networkx
     except ImportError:
-        from Bio import MissingPythonDependencyError
         raise MissingPythonDependencyError(
-                "Install NetworkX if you want to use to_networkx.")
+            "Install NetworkX if you want to use to_networkx.")
 
     # NB (1/2010): the networkx API stabilized at v.1.0
     # 1.0+: edges accept arbitrary data as kwargs, weights are floats
@@ -75,7 +75,7 @@ def to_networkx(tree):
 
 
 def draw_graphviz(tree, label_func=str, prog='twopi', args='',
-        node_color='#c0deff', **kwargs):
+                  node_color='#c0deff', **kwargs):
     """Display a tree or clade as a graph, using the graphviz engine.
 
     Requires NetworkX, matplotlib, Graphviz and either PyGraphviz or pydot.
@@ -105,6 +105,13 @@ def draw_graphviz(tree, label_func=str, prog='twopi', args='',
             up the desired value without checking if the intermediate attributes
             are available:
 
+                >>> from Bio import Phylo, AlignIO
+                >>> from Bio.Phylo.TreeConstruction import DistanceCalculator, DistanceTreeConstructor
+                >>> constructor = DistanceTreeConstructor()
+                >>> aln = AlignIO.read(open('Tests/TreeConstruction/msa.phy'), 'phylip')
+                >>> calculator = DistanceCalculator('identity')
+                >>> dm = calculator.get_distance(aln)
+                >>> tree = constructor.upgma(dm)
                 >>> Phylo.draw_graphviz(tree, lambda n: n.taxonomies[0].code)
 
         prog : string
@@ -118,32 +125,56 @@ def draw_graphviz(tree, label_func=str, prog='twopi', args='',
             Options passed to the external graphviz program.  Normally not
             needed, but offered here for completeness.
 
-    Example
-    -------
-
+    Examples
+    --------
     >>> import pylab
     >>> from Bio import Phylo
     >>> tree = Phylo.read('ex/apaf.xml', 'phyloxml')
     >>> Phylo.draw_graphviz(tree)
     >>> pylab.show()
     >>> pylab.savefig('apaf.png')
+
     """
+    # Deprecated in Biopython 1.70 (#1247)
+    import warnings
+    from Bio import BiopythonDeprecationWarning
+    warnings.warn("draw_graphviz is deprecated; use Bio.Phylo.draw instead",
+                  BiopythonDeprecationWarning)
+
     try:
         import networkx
     except ImportError:
-        from Bio import MissingPythonDependencyError
         raise MissingPythonDependencyError(
-                "Install NetworkX if you want to use to_networkx.")
+            "Install NetworkX if you want to use to_networkx.")
 
     G = to_networkx(tree)
-    Gi = networkx.convert_node_labels_to_integers(G, discard_old_labels=False)
     try:
-        posi = networkx.graphviz_layout(Gi, prog, args=args)
+        # NetworkX version 1.8 or later (2013-01-20)
+        Gi = networkx.convert_node_labels_to_integers(G,
+                                                      label_attribute='label')
+        int_labels = {}
+        for integer, nodeattrs in Gi.node.items():
+            int_labels[nodeattrs['label']] = integer
+    except TypeError:
+        # Older NetworkX versions (before 1.8)
+        Gi = networkx.convert_node_labels_to_integers(G,
+                                                      discard_old_labels=False)
+        int_labels = Gi.node_labels
+
+    try:
+        if hasattr(networkx, 'graphviz_layout'):
+            # networkx versions before 1.11 (#1247)
+            graphviz_layout = networkx.graphviz_layout
+        else:
+            # networkx version 1.11
+            graphviz_layout = networkx.drawing.nx_agraph.graphviz_layout
+        posi = graphviz_layout(Gi, prog, args=args)
     except ImportError:
         raise MissingPythonDependencyError(
-                "Install PyGraphviz or pydot if you want to use draw_graphviz.")
+            "Install PyGraphviz or pydot if you want to use draw_graphviz.")
 
     def get_label_mapping(G, selection):
+        """Apply the user-specified node relabeling."""
         for node in G.nodes():
             if (selection is None) or (node in selection):
                 try:
@@ -157,7 +188,7 @@ def draw_graphviz(tree, label_func=str, prog='twopi', args='',
         labels = dict(get_label_mapping(G, set(kwargs['nodelist'])))
     else:
         labels = dict(get_label_mapping(G, None))
-    kwargs['nodelist'] = labels.keys()
+    kwargs['nodelist'] = list(labels.keys())
     if 'edge_color' not in kwargs:
         kwargs['edge_color'] = [isinstance(e[2], dict) and
                                 e[2].get('color', 'k') or 'k'
@@ -167,11 +198,12 @@ def draw_graphviz(tree, label_func=str, prog='twopi', args='',
                            e[2].get('width', 1.0) or 1.0
                            for e in G.edges(data=True)]
 
-    posn = dict((n, posi[Gi.node_labels[n]]) for n in G)
-    networkx.draw(G, posn, labels=labels, node_color=node_color, **kwargs)
+    posn = {n: posi[int_labels[n]] for n in G}
+    networkx.draw(G, posn, labels=labels, with_labels=True,
+                  node_color=node_color, **kwargs)
 
 
-def draw_ascii(tree, file=sys.stdout, column_width=80):
+def draw_ascii(tree, file=None, column_width=80):
     """Draw an ascii-art phylogram of the given tree.
 
     The printed result looks like::
@@ -189,10 +221,15 @@ def draw_ascii(tree, file=sys.stdout, column_width=80):
 
     :Parameters:
         file : file-like object
-            File handle opened for writing the output drawing.
+            File handle opened for writing the output drawing. (Default:
+            standard output)
         column_width : int
             Total number of text columns used by the drawing.
+
     """
+    if file is None:
+        file = sys.stdout
+
     taxa = tree.get_terminals()
     # Some constants for the drawing calculations
     max_label_width = max(len(str(taxon)) for taxon in taxa)
@@ -203,17 +240,17 @@ def draw_ascii(tree, file=sys.stdout, column_width=80):
         """Create a mapping of each clade to its column position."""
         depths = tree.depths()
         # If there are no branch lengths, assume unit branch lengths
-        if not max(depths.itervalues()):
+        if max(depths.values()) == 0:
             depths = tree.depths(unit_branch_lengths=True)
         # Potential drawing overflow due to rounding -- 1 char per tree layer
         fudge_margin = int(math.ceil(math.log(len(taxa), 2)))
-        cols_per_branch_unit = ((drawing_width - fudge_margin)
-                                / float(max(depths.itervalues())))
-        return dict((clade, int(round(blen*cols_per_branch_unit + 0.5)))
-                    for clade, blen in depths.iteritems())
+        cols_per_branch_unit = ((drawing_width - fudge_margin) /
+                                float(max(depths.values())))
+        return {clade: int(blen * cols_per_branch_unit + 1.0)
+                for clade, blen in depths.items()}
 
     def get_row_positions(tree):
-        positions = dict((taxon, 2*idx) for idx, taxon in enumerate(taxa))
+        positions = {taxon: 2 * idx for idx, taxon in enumerate(taxa)}
 
         def calc_row(clade):
             for subclade in clade:
@@ -228,7 +265,7 @@ def draw_ascii(tree, file=sys.stdout, column_width=80):
     col_positions = get_col_positions(tree)
     row_positions = get_row_positions(tree)
     char_matrix = [[' ' for x in range(drawing_width)]
-                    for y in range(drawing_height)]
+                   for y in range(drawing_height)]
 
     def draw_clade(clade, startcol):
         thiscol = col_positions[clade]
@@ -240,14 +277,14 @@ def draw_ascii(tree, file=sys.stdout, column_width=80):
             # Draw a vertical line
             toprow = row_positions[clade.clades[0]]
             botrow = row_positions[clade.clades[-1]]
-            for row in range(toprow+1, botrow+1):
+            for row in range(toprow + 1, botrow + 1):
                 char_matrix[row][thiscol] = '|'
             # NB: Short terminal branches need something to stop rstrip()
             if (col_positions[clade.clades[0]] - thiscol) < 2:
                 char_matrix[toprow][thiscol] = ','
             # Draw descendents
             for child in clade:
-                draw_clade(child, thiscol+1)
+                draw_clade(child, thiscol + 1)
 
     draw_clade(tree.root, 0)
     # Print the complete drawing
@@ -255,14 +292,14 @@ def draw_ascii(tree, file=sys.stdout, column_width=80):
         line = ''.join(row).rstrip()
         # Add labels for terminal taxa in the right margin
         if idx % 2 == 0:
-            line += ' ' + str(taxa[idx//2])
+            line += ' ' + str(taxa[idx // 2])
         file.write(line + '\n')
     file.write('\n')
 
 
 def draw(tree, label_func=str, do_show=True, show_confidence=True,
-        # For power users
-        axes=None, branch_labels=None, *args, **kwargs):
+         # For power users
+         axes=None, branch_labels=None, label_colors=None, *args, **kwargs):
     """Plot the given tree using matplotlib (or pylab).
 
     The graphic is a rooted tree, drawn with roughly the same algorithm as
@@ -275,6 +312,13 @@ def draw(tree, label_func=str, do_show=True, show_confidence=True,
 
     Example using the pyplot options 'axhspan' and 'axvline':
 
+    >>> from Bio import Phylo, AlignIO
+    >>> from Bio.Phylo.TreeConstruction import DistanceCalculator, DistanceTreeConstructor
+    >>> constructor = DistanceTreeConstructor()
+    >>> aln = AlignIO.read(open('Tests/TreeConstruction/msa.phy'), 'phylip')
+    >>> calculator = DistanceCalculator('identity')
+    >>> dm = calculator.get_distance(aln)
+    >>> tree = constructor.upgma(dm)
     >>> Phylo.draw(tree, axhspan=((0.25, 7.75), {'facecolor':'0.5'}),
     ...     axvline={'x':'0', 'ymin':'0', 'ymax':'1'})
 
@@ -304,17 +348,20 @@ def draw(tree, label_func=str, do_show=True, show_confidence=True,
             But if you would like to alter the formatting of confidence values,
             or label the branches with something other than confidence, then use
             this option.
-    """
+        label_colors : dict or callable
+            A function or a dictionary specifying the color of the tip label.
+            If the tip label can't be found in the dict or label_colors is
+            None, the label will be shown in black.
 
+    """
     try:
         import matplotlib.pyplot as plt
     except ImportError:
         try:
             import pylab as plt
         except ImportError:
-            from Bio import MissingPythonDependencyError
             raise MissingPythonDependencyError(
-                    "Install matplotlib or pylab if you want to use draw.")
+                "Install matplotlib or pylab if you want to use draw.")
 
     import matplotlib.collections as mpcollections
 
@@ -334,7 +381,7 @@ def draw(tree, label_func=str, do_show=True, show_confidence=True,
                     # phyloXML supports multiple confidences
                     return '/'.join(conf2str(cnf.value)
                                     for cnf in clade.confidences)
-                if clade.confidence:
+                if clade.confidence is not None:
                     return conf2str(clade.confidence)
                 return None
         else:
@@ -344,10 +391,25 @@ def draw(tree, label_func=str, do_show=True, show_confidence=True,
         def format_branch_label(clade):
             return branch_labels.get(clade)
     else:
-        assert callable(branch_labels), \
-                "branch_labels must be either a dict or a callable (function)"
+        if not callable(branch_labels):
+            raise TypeError("branch_labels must be either a "
+                            "dict or a callable (function)")
         format_branch_label = branch_labels
 
+    # options for displaying label colors.
+    if label_colors:
+        if callable(label_colors):
+            def get_label_color(label):
+                return label_colors(label)
+        else:
+            # label_colors is presumed to be a dict
+            def get_label_color(label):
+                return label_colors.get(label, 'black')
+    else:
+        def get_label_color(label):
+            # if label_colors is not specified, use black
+            return 'black'
+
     # Layout
 
     def get_x_positions(tree):
@@ -357,7 +419,7 @@ def draw(tree, label_func=str, do_show=True, show_confidence=True,
         """
         depths = tree.depths()
         # If there are no branch lengths, assume unit branch lengths
-        if not max(depths.itervalues()):
+        if not max(depths.values()):
             depths = tree.depths(unit_branch_lengths=True)
         return depths
 
@@ -369,8 +431,8 @@ def draw(tree, label_func=str, do_show=True, show_confidence=True,
         """
         maxheight = tree.count_terminals()
         # Rows are defined by the tips
-        heights = dict((tip, maxheight - i)
-                for i, tip in enumerate(reversed(tree.get_terminals())))
+        heights = {tip: maxheight - i
+                   for i, tip in enumerate(reversed(tree.get_terminals()))}
 
         # Internal nodes: place at midpoint of children
         def calc_row(clade):
@@ -379,7 +441,7 @@ def draw(tree, label_func=str, do_show=True, show_confidence=True,
                     calc_row(subclade)
             # Closure over heights
             heights[clade] = (heights[clade.clades[0]] +
-                                heights[clade.clades[-1]]) / 2.0
+                              heights[clade.clades[-1]]) / 2.0
 
         if tree.root.clades:
             calc_row(tree.root)
@@ -402,16 +464,16 @@ def draw(tree, label_func=str, do_show=True, show_confidence=True,
         Graphical formatting of the lines representing clades in the plot can be
         customized by altering this function.
         """
-        if (use_linecollection==False and orientation=='horizontal'):
+        if not use_linecollection and orientation == 'horizontal':
             axes.hlines(y_here, x_start, x_here, color=color, lw=lw)
-        elif (use_linecollection==True and orientation=='horizontal'):
+        elif use_linecollection and orientation == 'horizontal':
             horizontal_linecollections.append(mpcollections.LineCollection(
-            [[(x_start,y_here), (x_here,y_here)]], color=color, lw=lw),)
-        elif (use_linecollection==False and orientation=='vertical'):
+                [[(x_start, y_here), (x_here, y_here)]], color=color, lw=lw),)
+        elif not use_linecollection and orientation == 'vertical':
             axes.vlines(x_here, y_bot, y_top, color=color)
-        elif (use_linecollection==True and orientation=='vertical'):
+        elif use_linecollection and orientation == 'vertical':
             vertical_linecollections.append(mpcollections.LineCollection(
-            [[(x_here,y_bot), (x_here,y_top)]], color=color, lw=lw),)
+                [[(x_here, y_bot), (x_here, y_top)]], color=color, lw=lw),)
 
     def draw_clade(clade, x_start, color, lw):
         """Recursively draw a tree, down from the given clade."""
@@ -424,23 +486,25 @@ def draw(tree, label_func=str, do_show=True, show_confidence=True,
             lw = clade.width * plt.rcParams['lines.linewidth']
         # Draw a horizontal line from start to here
         draw_clade_lines(use_linecollection=True, orientation='horizontal',
-            y_here=y_here, x_start=x_start, x_here=x_here, color='black', lw=lw)
+                         y_here=y_here, x_start=x_start, x_here=x_here, color=color, lw=lw)
         # Add node/taxon labels
         label = label_func(clade)
         if label not in (None, clade.__class__.__name__):
-            axes.text(x_here, y_here, ' %s' % label, verticalalignment='center')
+            axes.text(x_here, y_here, ' %s' %
+                      label, verticalalignment='center',
+                      color=get_label_color(label))
         # Add label above the branch (optional)
         conf_label = format_branch_label(clade)
         if conf_label:
-            axes.text(0.5*(x_start + x_here), y_here, conf_label,
-                    fontsize='small', horizontalalignment='center')
+            axes.text(0.5 * (x_start + x_here), y_here, conf_label,
+                      fontsize='small', horizontalalignment='center')
         if clade.clades:
             # Draw a vertical line connecting all children
             y_top = y_posns[clade.clades[0]]
             y_bot = y_posns[clade.clades[-1]]
             # Only apply widths to horizontal lines, like Archaeopteryx
             draw_clade_lines(use_linecollection=True, orientation='vertical',
-                x_here=x_here, y_bot=y_bot, y_top=y_top, color='black', lw=lw)
+                             x_here=x_here, y_bot=y_bot, y_top=y_top, color=color, lw=lw)
             # Draw descendents
             for child in clade:
                 draw_clade(child, x_here, color, lw)
@@ -461,22 +525,22 @@ def draw(tree, label_func=str, do_show=True, show_confidence=True,
     axes.set_xlabel('branch length')
     axes.set_ylabel('taxa')
     # Add margins around the tree to prevent overlapping the axes
-    xmax = max(x_posns.itervalues())
+    xmax = max(x_posns.values())
     axes.set_xlim(-0.05 * xmax, 1.25 * xmax)
     # Also invert the y-axis (origin at the top)
     # Add a small vertical margin, but avoid including 0 and N+1 on the y axis
-    axes.set_ylim(max(y_posns.itervalues()) + 0.8, 0.2)
+    axes.set_ylim(max(y_posns.values()) + 0.8, 0.2)
 
     # Parse and process key word arguments as pyplot options
-    for key, value in kwargs.iteritems():
+    for key, value in kwargs.items():
         try:
             # Check that the pyplot option input is iterable, as required
             [i for i in value]
         except TypeError:
             raise ValueError('Keyword argument "%s=%s" is not in the format '
-                'pyplot_option_name=(tuple), pyplot_option_name=(tuple, dict),'
-                ' or pyplot_option_name=(dict) '
-                % (key, value))
+                             'pyplot_option_name=(tuple), pyplot_option_name=(tuple, dict),'
+                             ' or pyplot_option_name=(dict) '
+                             % (key, value))
         if isinstance(value, dict):
             getattr(plt, str(key))(**dict(value))
         elif not (isinstance(value[0], tuple)):
