@@ -1,9 +1,10 @@
 #!/usr/bin/env python
-# Copyright 2013 by Iddo Friedberg idoerg@gmail.com
+# Copyright 2013, 2016 by Iddo Friedberg idoerg@gmail.com
 # All rights reserved.
-# This code is part of the Biopython distribution and governed by its
-# license.  Please see the LICENSE file that should have been included
-# as part of this package.
+# This file is part of the Biopython distribution and governed by your
+# choice of the "Biopython License Agreement" or the "BSD 3-Clause License".
+# Please see the LICENSE file that should have been included as part of this
+# package.
 """Parsers for the GAF, GPA and GPI formats from UniProt-GOA.
 
 Uniprot-GOA README + GAF format description:
@@ -18,8 +19,9 @@ gp_information (GPI format) README:
 ftp://ftp.ebi.ac.uk/pub/databases/GO/goa/UNIPROT/gp_information_readme
 """
 
+from __future__ import print_function
+
 import copy
-import sys
 
 from Bio._py3k import zip
 
@@ -28,98 +30,97 @@ from Bio._py3k import zip
 # GAF version 2.0
 
 GAF20FIELDS = ['DB',
-        'DB_Object_ID',
-        'DB_Object_Symbol',
-        'Qualifier',
-        'GO_ID',
-        'DB:Reference',
-        'Evidence',
-        'With',
-        'Aspect',
-        'DB_Object_Name',
-        'Synonym',
-        'DB_Object_Type',
-        'Taxon_ID',
-        'Date',
-        'Assigned_By',
-        'Annotation_Extension',
-        'Gene_Product_Form_ID']
+               'DB_Object_ID',
+               'DB_Object_Symbol',
+               'Qualifier',
+               'GO_ID',
+               'DB:Reference',
+               'Evidence',
+               'With',
+               'Aspect',
+               'DB_Object_Name',
+               'Synonym',
+               'DB_Object_Type',
+               'Taxon_ID',
+               'Date',
+               'Assigned_By',
+               'Annotation_Extension',
+               'Gene_Product_Form_ID']
 
 # GAF version 1.0
 GAF10FIELDS = ['DB',
-        'DB_Object_ID',
-        'DB_Object_Symbol',
-        'Qualifier',
-        'GO_ID',
-        'DB:Reference',
-        'Evidence',
-        'With',
-        'Aspect',
-        'DB_Object_Name',
-        'Synonym',
-        'DB_Object_Type',
-        'Taxon_ID',
-        'Date',
-        'Assigned_By']
-
+               'DB_Object_ID',
+               'DB_Object_Symbol',
+               'Qualifier',
+               'GO_ID',
+               'DB:Reference',
+               'Evidence',
+               'With',
+               'Aspect',
+               'DB_Object_Name',
+               'Synonym',
+               'DB_Object_Type',
+               'Taxon_ID',
+               'Date',
+               'Assigned_By']
 
 # GPA version 1.0
 GPA10FIELDS = [
-      'DB',
-      'DB_Object_ID',
-      'Qualifier',
-      'GO_ID',
-      'DB:Reference',
-      'Evidence code',
-      'With',
-      'Interacting_taxon_ID',
-      'Date',
-      'Assigned_by',
-      'Annotation_Extension',
-      'Spliceform_ID']
+    'DB',
+    'DB_Object_ID',
+    'Qualifier',
+    'GO_ID',
+    'DB:Reference',
+    'Evidence code',
+    'With',
+    'Interacting_taxon_ID',
+    'Date',
+    'Assigned_by',
+    'Annotation_Extension',
+    'Spliceform_ID']
 
 # GPA version 1.1
 GPA11FIELDS = [
-      'DB',
-      'DB_Object_ID',
-      'Qualifier',
-      'GO_ID',
-      'DB:Reference',
-      'ECO_Evidence_code',
-      'With',
-      'Interacting_taxon_ID',
-      'Date',
-      'Assigned_by',
-      'Annotation Extension',
-      'Annotation_Properties']
+    'DB',
+    'DB_Object_ID',
+    'Qualifier',
+    'GO_ID',
+    'DB:Reference',
+    'ECO_Evidence_code',
+    'With',
+    'Interacting_taxon_ID',
+    'Date',
+    'Assigned_by',
+    'Annotation Extension',
+    'Annotation_Properties']
 
 # GPI version 1.0
 GPI10FIELDS = [
-      'DB',
-      'DB_subset',
-      'DB_Object_ID',
-      'DB_Object_Symbol',
-      'DB_Object_Name',
-      'DB_Object_Synonym',
-      'DB_Object_Type',
-      'Taxon',
-      'Annotation_Target_Set',
-      'Annotation_Completed',
-      'Parent_Object_ID']
+    'DB',
+    'DB_subset',
+    'DB_Object_ID',
+    'DB_Object_Symbol',
+    'DB_Object_Name',
+    'DB_Object_Synonym',
+    'DB_Object_Type',
+    'Taxon',
+    'Annotation_Target_Set',
+    'Annotation_Completed',
+    'Parent_Object_ID']
 
 # GPI version 1.1
 GPI11FIELDS = [
-      'DB_Object_ID',
-      'DB_Object_Symbol',
-      'DB_Object_Name',
-      'DB_Object_Synonym',
-      'DB_Object_Type',
-      'Taxon',
-      'Parent_Object_ID',
-      'DB_Xref',
-      'Gene_Product_Properties',
-      'Annotation_Target_Set',
-      'GO_Annotation_Complete']
+    'DB_Object_ID',
+    'DB_Object_Symbol',
+    'DB_Object_Name',
+    'DB_Object_Synonym',
+    'DB_Object_Type',
+    'Taxon',
+    'Parent_Object_ID',
+    'DB_Xref',
+    'Gene_Product_Properties',
+    'Annotation_Target_Set',
+    'GO_Annotation_Complete']
 
 
 def _gpi10iterator(handle):
@@ -134,8 +135,8 @@ def _gpi10iterator(handle):
         inrec = inline.rstrip('\n').split('\t')
         if len(inrec) == 1:
             continue
-        inrec[5] = inrec[5].split('|') # DB_Object_Synonym(s)
-        inrec[8] = inrec[8].split('|') # Annotation_Target_Set
+        inrec[5] = inrec[5].split('|')  # DB_Object_Synonym(s)
+        inrec[8] = inrec[8].split('|')  # Annotation_Target_Set
         yield dict(zip(GPI10FIELDS, inrec))
 
 
@@ -151,10 +152,10 @@ def _gpi11iterator(handle):
         inrec = inline.rstrip('\n').split('\t')
         if len(inrec) == 1:
             continue
-        inrec[2] = inrec[2].split('|') # DB_Object_Name
-        inrec[3] = inrec[3].split('|') # DB_Object_Synonym(s)
-        inrec[7] = inrec[7].split('|') # DB_Xref(s)
-        inrec[8] = inrec[8].split('|') # Properties
+        inrec[2] = inrec[2].split('|')  # DB_Object_Name
+        inrec[3] = inrec[3].split('|')  # DB_Object_Synonym(s)
+        inrec[7] = inrec[7].split('|')  # DB_Xref(s)
+        inrec[8] = inrec[8].split('|')  # Properties
         yield dict(zip(GPI11FIELDS, inrec))
 
 
@@ -168,11 +169,17 @@ def gpi_iterator(handle):
     """
     inline = handle.readline()
     if inline.strip() == '!gpi-version: 1.1':
-        sys.stderr.write("gpi 1.1\n")
+        # sys.stderr.write("gpi 1.1\n")
         return _gpi11iterator(handle)
-    else:
-        sys.stderr.write("gpi 1.0\n")
+    elif inline.strip() == '!gpi-version: 1.0':
+        # sys.stderr.write("gpi 1.0\n")
         return _gpi10iterator(handle)
+    elif inline.strip() == '!gpi-version: 2.1':
+        # sys.stderr.write("gpi 2.1\n")
+        # return _gpi20iterator(handle)
+        raise NotImplementedError("Sorry, parsing GPI version 2 not implemented yet.")
+    else:
+        raise ValueError('Unknown GPI version {0}\n'.format(inline))
 
 
 def _gpa10iterator(handle):
@@ -182,17 +189,16 @@ def _gpa10iterator(handle):
     file which is in the GPA 1.0 format. Do not call directly. Rather,
     use the gpaiterator function.
     """
-
     for inline in handle:
         if inline[0] == '!':
             continue
         inrec = inline.rstrip('\n').split('\t')
         if len(inrec) == 1:
             continue
-        inrec[2] = inrec[2].split('|') # Qualifier
-        inrec[4] = inrec[4].split('|') # DB:Reference(s)
-        inrec[6] = inrec[6].split('|') # With
-        inrec[10] = inrec[10].split('|') # Annotation extension
+        inrec[2] = inrec[2].split('|')  # Qualifier
+        inrec[4] = inrec[4].split('|')  # DB:Reference(s)
+        inrec[6] = inrec[6].split('|')  # With
+        inrec[10] = inrec[10].split('|')  # Annotation extension
         yield dict(zip(GPA10FIELDS, inrec))
 
 
@@ -209,15 +215,15 @@ def _gpa11iterator(handle):
         inrec = inline.rstrip('\n').split('\t')
         if len(inrec) == 1:
             continue
-        inrec[2] = inrec[2].split('|') # Qualifier
-        inrec[4] = inrec[4].split('|') # DB:Reference(s)
-        inrec[6] = inrec[6].split('|') # With
-        inrec[10] = inrec[10].split('|') # Annotation extension
+        inrec[2] = inrec[2].split('|')  # Qualifier
+        inrec[4] = inrec[4].split('|')  # DB:Reference(s)
+        inrec[6] = inrec[6].split('|')  # With
+        inrec[10] = inrec[10].split('|')  # Annotation extension
         yield dict(zip(GPA11FIELDS, inrec))
 
 
 def gpa_iterator(handle):
-    """Wrapper function: read GPA format files.
+    """Read GPA format files.
 
     This function should be called to read a
     gene_association.goa_uniprot file. Reads the first record and
@@ -225,11 +231,13 @@ def gpa_iterator(handle):
     """
     inline = handle.readline()
     if inline.strip() == '!gpa-version: 1.1':
-        sys.stderr.write("gpa 1.1\n")
+        # sys.stderr.write("gpa 1.1\n")
         return _gpa11iterator(handle)
-    else:
-        sys.stderr.write("gpa 1.0\n")
+    elif inline.strip() == '!gpa-version: 1.0':
+        # sys.stderr.write("gpa 1.0\n")
         return _gpa10iterator(handle)
+    else:
+        raise ValueError('Unknown GPA version {0}\n'.format(inline))
 
 
 def _gaf20iterator(handle):
@@ -313,36 +321,80 @@ def _gaf20byproteiniterator(handle):
 
 
 def gafbyproteiniterator(handle):
-    """Iterates over records in a gene association file.
+    """Iterate over records in a gene association file.
 
     Returns a list of all consecutive records with the same DB_Object_ID
     This function should be called to read a
     gene_association.goa_uniprot file. Reads the first record and
     returns a gaf 2.0 or a gaf 1.0 iterator as needed
+    2016-04-09: added GAF 2.1 iterator & fixed bug in iterator assignment
+    In the meantime GAF 2.1 uses the GAF 2.0 iterator
     """
     inline = handle.readline()
     if inline.strip() == '!gaf-version: 2.0':
-        sys.stderr.write("gaf 2.0\n")
+        # sys.stderr.write("gaf 2.0\n")
+        return _gaf20byproteiniterator(handle)
+    elif inline.strip() == '!gaf-version: 1.0':
+        # sys.stderr.write("gaf 1.0\n")
+        return _gaf10byproteiniterator(handle)
+    elif inline.strip() == '!gaf-version: 2.1':
+        # Handle GAF 2.1 as GAF 2.0 for now TODO: fix
+        # sys.stderr.write("gaf 2.1\n")
         return _gaf20byproteiniterator(handle)
     else:
-        sys.stderr.write("gaf 1.0\n")
-        return _gaf10byproteiniterator(handle)
+        raise ValueError('Unknown GAF version {0}\n'.format(inline))
 
 
 def gafiterator(handle):
-    """Iterate pver a GAF 1.0 or 2.0 file.
+    """Iterate over a GAF 1.0 or 2.0 file.
 
     This function should be called to read a
     gene_association.goa_uniprot file. Reads the first record and
     returns a gaf 2.0 or a gaf 1.0 iterator as needed
+
+    Example: open, read, interat and filter results.
+
+    Original data file has been trimed to ~600 rows.
+
+    Original source ftp://ftp.ebi.ac.uk/pub/databases/GO/goa/YEAST/goa_yeast.gaf.gz
+
+    >>> from Bio.UniProt.GOA import gafiterator, record_has
+    >>> Evidence = {'Evidence': set(['ND'])}
+    >>> Synonym = {'Synonym': set(['YA19A_YEAST', 'YAL019W-A'])}
+    >>> Taxon_ID = {'Taxon_ID': set(['taxon:559292'])}
+    >>> with open('UniProt/goa_yeast.gaf', 'r') as handle:
+    ...     for rec in gafiterator(handle):
+    ...         if record_has(rec, Taxon_ID) and record_has(rec, Evidence) and record_has(rec, Synonym):
+    ...             for key in ('DB_Object_Name', 'Evidence', 'Synonym', 'Taxon_ID'):
+    ...                 print(rec[key])
+    ...
+    Putative uncharacterized protein YAL019W-A
+    ND
+    ['YA19A_YEAST', 'YAL019W-A']
+    ['taxon:559292']
+    Putative uncharacterized protein YAL019W-A
+    ND
+    ['YA19A_YEAST', 'YAL019W-A']
+    ['taxon:559292']
+    Putative uncharacterized protein YAL019W-A
+    ND
+    ['YA19A_YEAST', 'YAL019W-A']
+    ['taxon:559292']
+
     """
     inline = handle.readline()
     if inline.strip() == '!gaf-version: 2.0':
-        sys.stderr.write("gaf 2.0\n")
+        # sys.stderr.write("gaf 2.0\n")
         return _gaf20iterator(handle)
-    else:
-        sys.stderr.write("gaf 1.0\n")
+    elif inline.strip() == '!gaf-version: 2.1':
+        # sys.stderr.write("gaf 2.1\n")
+        # Handle GAF 2.1 as GAF 2.0 for now. TODO: fix
+        return _gaf20iterator(handle)
+    elif inline.strip() == '!gaf-version: 1.0':
+        # sys.stderr.write("gaf 1.0\n")
         return _gaf10iterator(handle)
+    else:
+        raise ValueError('Unknown GAF version {0}\n'.format(inline))
 
 
 def writerec(outrec, handle, fields=GAF20FIELDS):
@@ -377,7 +429,7 @@ def writebyproteinrec(outprotrec, handle, fields=GAF20FIELDS):
 
 
 def record_has(inrec, fieldvals):
-    """Accepts a record, and a dictionary of field values.
+    """Accept a record, and a dictionary of field values.
 
     The format is {'field_name': set([val1, val2])}.
     If any field in the record has  a matching value, the function returns
@@ -386,7 +438,7 @@ def record_has(inrec, fieldvals):
     retval = False
     for field in fieldvals:
         if isinstance(inrec[field], str):
-            set1 = set([inrec[field]])
+            set1 = {inrec[field]}
         else:
             set1 = set(inrec[field])
         if (set1 & fieldvals[field]):
@@ -395,15 +447,6 @@ def record_has(inrec, fieldvals):
     return retval
 
 
-if __name__ == '__main__':
-    """Example: read and filter a GAF file.
-
-    Write only S. cerevisiae records, but remove all
-    records with IEA evidence
-    """
-    banned = {'Evidence': set(['IEA', 'EXP'])}
-    allowed = {'Taxon_ID': set(['taxon:4932'])}
-    for inrec in gafiterator(open(sys.argv[1])):
-        if record_has(inrec, allowed) and \
-               not record_has(inrec, banned):
-            writerec(inrec, sys.stdout, GAF10FIELDS)
+if __name__ == "__main__":
+    from Bio._utils import run_doctest
+    run_doctest(verbose=0)
