@@ -32,9 +32,9 @@ Here `###` is the 3 digit number REBASE release number (e.g. 312). The first
 digit is the last digit of the year (e.g. 3 for 2013) and the two last the
 month (e.g. 12 for December).
 
-There files are available by FTP from ftp://ftp.neb.com/pub/rebase/ which
-should allow automated fetching (the the update code and RanaConfig.py).
-In addition there are links on this HTML page which requires manual download
+These files are available by FTP from ftp://ftp.neb.com/pub/rebase/ which
+should allow automated fetching via ``rebase_update.py``.
+In addition there are links on this HTML page which allows manual download
 and renaming of the files: http://rebase.neb.com/rebase/rebase.f37.html
 This Python file is intended to be used via the scripts in
 `Scripts/Restriction/*.py` only.
@@ -63,8 +63,7 @@ from Bio.Restriction.Restriction import Blunt, Ov5, Ov3
 from Bio.Restriction.Restriction import NotDefined, Defined, Ambiguous
 from Bio.Restriction.Restriction import Commercially_available, Not_available
 
-import Bio.Restriction.RanaConfig as config
-from rebase_update import RebaseUpdate
+from rebase_update import release_number, get_files
 
 
 enzymedict = {}
@@ -119,20 +118,11 @@ def is_palindrome(sequence):
     return str(sequence) == str(sequence.reverse_complement())
 
 
-def LocalTime():
-    """Extension for emboss file for the current year and month."""
-    t = time.gmtime()
-    year = str(t.tm_year)[-1]
-    month = str(t.tm_mon)
-    if len(month) == 1:
-        month = '0' + month
-    return year + month
-
-
 class newenzyme(object):
-    """construct the attributes of the enzyme corresponding to 'name'."""
+    """Construct the attributes of the enzyme corresponding to 'name'."""
 
     def __init__(cls, name):
+        """Set up the enzyme's attributes."""
         cls.opt_temp = 37
         cls.inact_temp = 65
         cls.substrat = 'DNA'
@@ -322,6 +312,8 @@ class TypeCompiler(object):
                     dct.update({'scd5': None, 'scd3': None})
 
             class klass(type):
+                """Dynamically defined restriction enzyme class."""
+
                 def __new__(cls):
                     return type.__new__(cls, 'type%i' % n, ty, dct)
 
@@ -332,40 +324,34 @@ class TypeCompiler(object):
             n += 1
 
 
-start = """#!/usr/bin/env python
-#
-#      Restriction Analysis Libraries.
+start = '''#!/usr/bin/env python
 #      Copyright (C) 2004. Frederic Sohm.
 #
 # This code is part of the Biopython distribution and governed by its
 # license.  Please see the LICENSE file that should have been included
-# as part of this package.\n\
-#\n\
+# as part of this package.
+#
 # This file is automatically generated - do not edit it by hand! Instead,
 # use the tool Scripts/Restriction/ranacompiler.py which in turn uses
 # Scripts/Restriction/rebase_update.py and Bio/Restriction/RanaConfig.py
-#\n\
-# The following dictionaries used to be defined in one go, but that does
-# not work on Jython due to JVM limitations. Therefore we break this up
-# into steps, using temporary functions to avoid the JVM limits.
-#
-# Used REBASE emboss files version {} ({}).
+"""Restriction Analysis Libraries.
 
-""".format(LocalTime(), time.gmtime().tm_year)
+The following dictionaries used to be defined in one go, but that does
+not work on Jython due to JVM limitations. Therefore we break this up
+into steps, using temporary functions to avoid the JVM limits.
+
+Used REBASE emboss files version {} ({}).
+
+"""
+'''.format(release_number, time.gmtime().tm_year)
 
 
 class DictionaryBuilder(object):
+    """Builds ``Restriction_Dictionary.py`` from Rebase files.
 
-    def __init__(self, ftp_proxy=''):
-        """DictionaryBuilder([ftp_proxy])->DictionaryBuilder instance.
-
-        If the emboss files used for the construction need to be updated this
-        class will download them if the ftp connection is correctly set.
-        either in RanaConfig.py or given at run time.
-
-        proxy is the ftp_proxy to use if any.
-        """
-        self.proxy = ftp_proxy or config.ftp_proxy
+    If the emboss files used for the construction need to be updated this
+    class will download them if the ftp connection is correctly set.
+    """
 
     def build_dict(self):
         """Construct dictionary and build files containing new dictionaries."""
@@ -403,9 +389,9 @@ class DictionaryBuilder(object):
             #   Now select the right type for the enzyme.
             #
             bases = cls.bases
-            clsbases = tuple([eval(x) for x in bases])
+            clsbases = tuple([eval(x) for x in bases])  # noqa: C407
             typestuff = ''
-            for n, t in tdct.items():
+            for t in tdct.values():
                 #
                 #   if the bases are the same. it is the right type.
                 #   create the enzyme and remember the type
@@ -430,7 +416,7 @@ class DictionaryBuilder(object):
             else:
                 enzlst = []
                 tydct = dict(typestuff.__dict__)
-                tydct = dict([(k, v) for k, v in tydct.items()
+                tydct = dict([(k, v) for k, v in tydct.items()  # noqa: C404
                               if k in commonattr])
                 enzlst.append(name)
                 typedict[typename] = (bases, enzlst)
@@ -590,7 +576,7 @@ class DictionaryBuilder(object):
         #
         #   first check if we have the last update:
         #
-        emboss_now = ['.'.join((x, LocalTime())) for x in embossnames]
+        emboss_now = ['.'.join((x, release_number)) for x in embossnames]
         update_needed = False
         # dircontent = os.listdir(config.Rebase) #    local database content
         dircontent = os.listdir(os.getcwd())
@@ -611,14 +597,11 @@ class DictionaryBuilder(object):
             #
             #   may be download the files.
             #
-            print('\n The rebase files are more than one month old.\
+            print('\n The rebase files are missing or more than one month old.\
             \n Would you like to update them before proceeding?(y/n)')
             r = _input(' update [n] >>> ')
             if r in ['y', 'yes', 'Y', 'Yes']:
-                updt = RebaseUpdate(self.proxy)
-                updt.openRebase()
-                updt.getfiles()
-                updt.close()
+                get_files()
                 print('\n Update complete. Creating the dictionaries.\n')
                 print('\n Using the files : %s' % ', '.join(emboss_now))
                 return tuple(open(os.path.join(base, n)) for n in emboss_now)
@@ -635,8 +618,7 @@ class DictionaryBuilder(object):
                             if file.startswith(name):
                                 break
                         else:
-                            pass
-                        raise NotFoundError
+                            raise NotFoundError
                     except NotFoundError:
                         print("\nNo %s file found. Upgrade is impossible.\n" %
                               name)
@@ -665,10 +647,10 @@ class DictionaryBuilder(object):
             last[0], last[-1] = last[-1], last[0]
 
         for number in last:
-            files = [(name, name + '.%s' % number) for name in embossnames]
+            files = [(name + '.%s' % number) for name in embossnames]
             strmess = '\nLast EMBOSS files found are :\n'
             try:
-                for name, file in files:
+                for file in files:
                     if os.path.isfile(os.path.join(base, file)):
                         strmess += '\t%s.\n' % file
                     else:
@@ -685,6 +667,7 @@ class DictionaryBuilder(object):
                 continue
 
     def parseline(self, line):
+        """Parse a line from the Rebase emboss_e.xxx file."""
         line = [line[0]] + \
             [line[1].upper()] + [int(i) for i in line[2:9]] + \
             line[9:]
@@ -884,13 +867,12 @@ class DictionaryBuilder(object):
         return line
 
     def removestart(self, file):
-        #
-        #   remove the heading of the file.
-        #
+        """Remove the header of the file."""
         return [l for l in itertools.dropwhile(lambda l:l.startswith('#'),
                                                file)]
 
     def getblock(self, file, index):
+        """Get a data block from the emboss_r file."""
         #
         #   emboss_r.txt, separation between blocks is //
         #
@@ -901,6 +883,7 @@ class DictionaryBuilder(object):
         return block, index
 
     def get(self, block):
+        """Get name, methylation information and suppliers."""
         #
         #   take what we want from the block.
         #   Each block correspond to one enzyme.
@@ -914,6 +897,7 @@ class DictionaryBuilder(object):
         return (block[0].strip(), bl3, block[5].strip())
 
     def information_mixer(self, file1, file2, file3):
+        """Combine extracted data from the three emboss_x.xxx files."""
         #
         #   Mix all the information from the 3 files and produce a coherent
         #   restriction record.
@@ -995,6 +979,7 @@ class DictionaryBuilder(object):
 
 
 def standalone():
+    """Set up for running as main."""
     parser = optparse.OptionParser()
     add = parser.add_option
 
@@ -1005,18 +990,13 @@ def standalone():
         help="compile and install the newly created file. "
         "default behaviour (without switch): "
         "Compile the enzymes and store them in the Updates folder")
-    add('-p', '--proxy',
-        action="store",
-        dest='ftp_proxy',
-        default='',
-        help="set the proxy to be used by the ftp connection.")
     options, args = parser.parse_args()
     return options, args
 
 
 if __name__ == '__main__':
     options, args = standalone()
-    Builder = DictionaryBuilder(options.ftp_proxy)
+    Builder = DictionaryBuilder()
     Builder.build_dict()
     if options.i:
         Builder.install_dict()
