@@ -8,7 +8,8 @@
 
 # Created: Sat Dec  2 16:02:17 2000
 # thomas@cbs.dtu.dk, http://www.cbs.dtu.dk/thomas
-# File: xbb_blastbg.py
+
+"""BLAST code for graphical Xbbtools tool."""
 
 from __future__ import print_function
 
@@ -29,11 +30,15 @@ from Bio.Blast.Applications import (NcbiblastnCommandline,
 
 
 class BlastDisplayer(object):
+    """A class for running and displaying a BLAST search."""
+
     def __init__(self, command_data, text_id=None):
+        """Take command data and notpad id."""
         self.command_data = command_data
         self.tid = text_id
 
     def RunCommand(self):
+        """Run the BLAST search."""
         self.fh_in, self.infile = tempfile.mkstemp()
         self.fh_out, self.outfile = tempfile.mkstemp()
 
@@ -85,6 +90,7 @@ class BlastDisplayer(object):
         self.UpdateResults()
 
     def UpdateResults(self):
+        """Write BLAST result data into notepad."""
         # open the oufile and displays new appended text
         self.tid.insert('end', 'BLAST is running...')
         while True:
@@ -97,13 +103,14 @@ class BlastDisplayer(object):
                 txt = fid.read()
                 self.tid.insert('end', txt)
                 self.tid.update()
-            except:
+            except Exception:
                 # text widget is detroyed, we assume the search
                 # has been cancelled
                 pass
         self.Exit()
 
     def Exit(self):
+        """Clean up on exit."""
         if os.path.exists(self.outfile):
             os.close(self.fh_out)
             os.remove(self.outfile)
@@ -115,13 +122,16 @@ class BlastDisplayer(object):
 
 
 class BlastWorker(threading.Thread):
+    """Allows multiple BLAST searches by threading."""
 
     def __init__(self, blast_command):
+        """Initialize the worker."""
         self.com = blast_command
         threading.Thread.__init__(self)
         self.finished = 0
 
     def run(self):
+        """Start worker."""
         try:
             self.com()
         except Exception as e:
@@ -129,6 +139,7 @@ class BlastWorker(threading.Thread):
                                    'BLAST error:\n\n' + str(e))
         self.finished = 1
 
+
 if __name__ == '__main__':
     os.system('python xbb_blast.py' +
               ' ATGACAAAGCTAATTATTCACTTGGTTTCAGACTCTTCTGTGCAAACTGC')
