@@ -107,7 +107,10 @@ def check_config(dbdriver, dbtype, dbhost, dbuser, dbpasswd, testdb):
         try:
             __import__(DBDRIVER)
         except ImportError:
-            message = "Install %s if you want to use %s with BioSQL " % (DBDRIVER, DBTYPE)
+            if DBDRIVER in ["MySQLdb"]:
+                message = "Install MySQLdb or mysqlclient if you want to use %s with BioSQL " % (DBTYPE)
+            else:
+                message = "Install %s if you want to use %s with BioSQL " % (DBDRIVER, DBTYPE)
             raise MissingExternalDependencyError(message)
 
     try:
@@ -135,7 +138,6 @@ def _do_db_cleanup():
 
     Relevant for MySQL and PostgreSQL.
     """
-
     if DBDRIVER in ["psycopg2", "pgdb"]:
         # first open a connection the database
         # notice that postgres doesn't have createdb privileges, so
@@ -320,11 +322,8 @@ class MultiReadTest(unittest.TestCase):
         del server["biosql-test"]
         del server["biosql-test2"]
         self.assertEqual(0, len(server))
-        try:
+        with self.assertRaises(KeyError):
             del server["non-existant-name"]
-            assert False, "Should have raised KeyError"
-        except KeyError:
-            pass
 
     def test_get_db_items(self):
         """Check list, keys, length etc."""
@@ -339,31 +338,25 @@ class MultiReadTest(unittest.TestCase):
         self.assertEqual(length, len(list(db.values())))
         if sys.version_info[0] == 2:
             # Check legacy methods for Python 2 as well:
-            self.assertEqual(length, len(list(db.iteritems())))
-            self.assertEqual(length, len(list(db.iterkeys())))
-            self.assertEqual(length, len(list(db.itervalues())))
+            self.assertEqual(length, len(list(db.iteritems())))  # noqa: B301
+            self.assertEqual(length, len(list(db.iterkeys())))  # noqa: B301
+            self.assertEqual(length, len(list(db.itervalues())))  # noqa: B301
         for (k1, r1), (k2, r2) in zip(zip(keys, items), db.items()):
             self.assertEqual(k1, k2)
             self.assertEqual(r1.id, r2.id)
         for k in keys:
             del db[k]
         self.assertEqual(0, len(db))
-        try:
+        with self.assertRaises(KeyError):
             del db["non-existant-name"]
-            assert False, "Should have raised KeyError"
-        except KeyError:
-            pass
 
     def test_cross_retrieval_of_items(self):
         """Test that valid ids can't be retrieved between namespaces."""
         db = self.db
         db2 = self.db2
         for db2_id in db2.keys():
-            try:
+            with self.assertRaises(KeyError):
                 rec = db[db2_id]
-                assert False, "Should have raised KeyError"
-            except KeyError:
-                pass
 
 
 class ReadTest(unittest.TestCase):
@@ -398,11 +391,8 @@ class ReadTest(unittest.TestCase):
         # Check we can delete the namespace...
         del server["biosql-test"]
         self.assertEqual(0, len(server))
-        try:
+        with self.assertRaises(KeyError):
             del server["non-existant-name"]
-            assert False, "Should have raised KeyError"
-        except KeyError:
-            pass
 
     def test_get_db_items(self):
         """Check list, keys, length etc."""
@@ -420,11 +410,8 @@ class ReadTest(unittest.TestCase):
         for k in keys:
             del db[k]
         self.assertEqual(0, len(db))
-        try:
+        with self.assertRaises(KeyError):
             del db["non-existant-name"]
-            assert False, "Should have raised KeyError"
-        except KeyError:
-            pass
 
     def test_lookup_items(self):
         """Test retrieval of items using various ids."""
@@ -536,6 +523,31 @@ class SeqInterfaceTest(unittest.TestCase):
             test = other + test_seq
             self.assertEqual(str(test), str(other) + str(test_seq))
 
+    def test_multiplication(self):
+        """Check can multiply DBSeq objects by integers."""
+        test_seq = self.item.seq
+        alphabet = test_seq.alphabet
+        tripled = test_seq * 3
+        # Test DBSeq.__mul__
+        self.assertTrue(isinstance(tripled, Seq))
+        self.assertFalse(isinstance(tripled, BioSeq.DBSeq))
+        self.assertEqual(tripled, str(test_seq) * 3)
+        self.assertEqual(tripled.alphabet, alphabet)
+        # Test DBSeq.__rmul__
+        tripled = 3 * test_seq
+        self.assertTrue(isinstance(tripled, Seq))
+        self.assertFalse(isinstance(tripled, BioSeq.DBSeq))
+        self.assertEqual(tripled, str(test_seq) * 3)
+        self.assertEqual(tripled.alphabet, alphabet)
+        # Test DBSeq.__imul__
+        original = self.item.seq
+        tripled = test_seq
+        tripled *= 3
+        self.assertTrue(isinstance(tripled, Seq))
+        self.assertFalse(isinstance(tripled, BioSeq.DBSeq))
+        self.assertEqual(tripled, str(original) * 3)
+        self.assertEqual(tripled.alphabet, alphabet)
+
     def test_seq_slicing(self):
         """Check that slices of sequences are retrieved properly."""
         test_seq = self.item.seq
@@ -668,11 +680,8 @@ class DeleteTest(unittest.TestCase):
         # Check we can delete the namespace...
         del server["biosql-test"]
         self.assertEqual(0, len(server))
-        try:
+        with self.assertRaises(KeyError):
             del server["non-existant-name"]
-            assert False, "Should have raised KeyError"
-        except KeyError:
-            pass
 
     def test_del_db_items(self):
         """Check all associated data is deleted from an item."""
@@ -730,6 +739,7 @@ class DupLoadTest(unittest.TestCase):
             # Note we don't do a specific exception handler because the
             # exception class will depend on which DB back end is in use.
             self.assertTrue(err.__class__.__name__ in ["IntegrityError",
+                                                       "UniqueViolation",
                                                        "AttributeError",
                                                        "OperationalError"],
                             err.__class__.__name__)
@@ -747,6 +757,7 @@ class DupLoadTest(unittest.TestCase):
         except Exception as err:
             # Good!
             self.assertTrue(err.__class__.__name__ in ["IntegrityError",
+                                                       "UniqueViolation",
                                                        "AttributeError"],
                             err.__class__.__name__)
             return
@@ -763,6 +774,7 @@ class DupLoadTest(unittest.TestCase):
         except Exception as err:
             # Good!
             self.assertTrue(err.__class__.__name__ in ["IntegrityError",
+                                                       "UniqueViolation",
                                                        "AttributeError"],
                             err.__class__.__name__)
             return
@@ -977,6 +989,7 @@ class InDepthLoadTest(unittest.TestCase):
         except Exception as err:
             # Good!
             self.assertTrue(err.__class__.__name__ in ["IntegrityError",
+                                                       "UniqueViolation",
                                                        "AttributeError"],
                             err.__class__.__name__)
             return
