@@ -12,15 +12,12 @@ Command line options::
 
     --help        -- show usage info
     --offline     -- skip tests which require internet access
-    -g;--generate -- write the output file for a test instead of comparing it.
-                     The name of the test to write the output for must be
-                     specified.
-    -v;--verbose  -- run tests with higher verbosity (does not affect our
-                     print-and-compare style unit tests).
+    -v;--verbose  -- run tests with higher verbosity
     <test_name>   -- supply the name of one (or more) tests to be run.
                      The .py file extension is optional.
     doctest       -- run the docstring tests.
 
+<test_name> and doctest, if supplied, must come after the other options.
 By default, all tests are run.
 """
 
@@ -29,7 +26,6 @@ from __future__ import print_function
 # standard modules
 import sys
 import os
-import re
 import getopt
 import time
 import traceback
@@ -38,6 +34,8 @@ import doctest
 import distutils.util
 import gc
 from io import BytesIO
+from pkgutil import iter_modules
+from setuptools import find_packages
 
 
 # Note, we want to be able to call run_tests.py BEFORE
@@ -77,88 +75,65 @@ def is_pypy():
 # The default verbosity (not verbose)
 VERBOSITY = 0
 
-# This is the list of modules containing docstring tests.
-# If you develop docstring tests for other modules, please add
-# those modules here. Please sort names alphabetically.
-DOCTEST_MODULES = [
-    "Bio.Align",
-    "Bio.Align.Applications._Clustalw",
-    "Bio.Align.Applications._ClustalOmega",
-    "Bio.Align.Applications._Dialign",
-    "Bio.Align.Applications._MSAProbs",
-    "Bio.Align.Applications._Mafft",
-    "Bio.Align.Applications._Muscle",
-    "Bio.Align.Applications._Probcons",
-    "Bio.Align.Applications._Prank",
-    "Bio.Align.Applications._TCoffee",
-    "Bio.AlignIO",
-    "Bio.AlignIO.StockholmIO",
-    "Bio.Alphabet",
-    "Bio.Alphabet.Reduced",
-    "Bio.Application",
-    "Bio.bgzf",
-    "Bio.codonalign",
-    "Bio.codonalign.codonalignment",
-    "Bio.codonalign.codonalphabet",
-    "Bio.codonalign.codonseq",
-    "Bio.Blast.Applications",
-    "Bio.Emboss.Applications",
-    "Bio.GenBank",
-    "Bio.Graphics.GenomeDiagram._Colors",
-    "Bio.KEGG.Compound",
-    "Bio.KEGG.Enzyme",
-    "Bio.KEGG.Gene",
-    "Bio.KEGG.KGML.KGML_parser",
-    "Bio.Nexus.Nexus",
-    "Bio.NMR.xpktools",
-    "Bio.motifs",
-    "Bio.motifs.applications._xxmotif",
-    "Bio.pairwise2",
-    "Bio.Phylo.Applications._Raxml",
-    "Bio.Phylo.Consensus",
-    "Bio.Phylo.BaseTree",
-    "Bio.SearchIO",
-    "Bio.SearchIO._model",
-    "Bio.SearchIO._model.query",
-    "Bio.SearchIO._model.hit",
-    "Bio.SearchIO._model.hsp",
-    "Bio.SearchIO.BlastIO",
-    "Bio.SearchIO.HmmerIO",
-    "Bio.SearchIO.FastaIO",
-    "Bio.SearchIO.BlatIO",
-    "Bio.SearchIO.ExonerateIO",
-    "Bio.Seq",
-    "Bio.SeqIO",
-    "Bio.SeqIO.AceIO",
-    "Bio.SeqIO.FastaIO",
-    "Bio.SeqIO.IgIO",
-    "Bio.SeqIO.InsdcIO",
-    "Bio.SeqIO.PhdIO",
-    "Bio.SeqIO.PirIO",
-    "Bio.SeqIO.QualityIO",
-    "Bio.SeqIO.SffIO",
-    "Bio.SeqIO.TabIO",
-    "Bio.SeqFeature",
-    "Bio.SeqRecord",
-    "Bio.SeqUtils",
-    "Bio.SeqUtils.CheckSum",
-    "Bio.SeqUtils.MeltingTemp",
-    "Bio.SeqUtils.ProtParam",
-    "Bio.Sequencing.Applications._Novoalign",
-    "Bio.Sequencing.Applications._bwa",
-    "Bio.Sequencing.Applications._samtools",
-    "Bio.SwissProt",
-    "Bio.UniProt.GOA",
-    "Bio.Wise",
-    "Bio.Wise.psw",
+# Following modules have historic failures. If you fix one of these
+# please remove here!
+EXCLUDE_DOCTEST_MODULES = [
+    'Bio.PDB',
+    'Bio.PDB.AbstractPropertyMap',
+    'Bio.Phylo.Applications._Fasttree',
+    'Bio.Phylo._io',
+    'Bio.Phylo.TreeConstruction',
+    'Bio.Phylo._utils',
 ]
+
+# Exclude modules with online activity
+# They are not excluded by default, use --offline to exclude them
+ONLINE_DOCTEST_MODULES = [
+    'Bio.Entrez',
+    'Bio.ExPASy',
+    'Bio.TogoWS',
+    ]
+
 # Silently ignore any doctests for modules requiring numpy!
-if numpy:
-    DOCTEST_MODULES.extend([
+if numpy is None:
+    EXCLUDE_DOCTEST_MODULES.extend([
         "Bio.Affy.CelFile",
+        "Bio.Cluster",
+        "Bio.KDTree",
+        "Bio.KDTree.KDTree",
+        "Bio.kNN",
+        "Bio.LogisticRegression",
+        "Bio.MarkovModel",
         "Bio.MaxEntropy",
+        "Bio.NaiveBayes",
+        "Bio.PDB.Chain",
+        "Bio.PDB.Dice",
+        "Bio.PDB.HSExposure",
+        "Bio.PDB.MMCIF2Dict",
+        "Bio.PDB.MMCIFParser",
+        "Bio.PDB.mmtf.DefaultParser",
+        "Bio.PDB.mmtf",
+        "Bio.PDB.Model",
+        "Bio.PDB.NACCESS",
+        "Bio.PDB.NeighborSearch",
+        "Bio.PDB.parse_pdb_header",
+        "Bio.PDB.PDBExceptions",
+        "Bio.PDB.PDBList",
+        "Bio.PDB.PDBParser",
         "Bio.PDB.Polypeptide",
+        "Bio.PDB.PSEA",
+        "Bio.PDB.QCPSuperimposer",
+        "Bio.PDB.Residue",
         "Bio.PDB.Selection",
+        "Bio.PDB.StructureAlignment",
+        "Bio.PDB.StructureBuilder",
+        "Bio.PDB.Structure",
+        "Bio.PDB.Superimposer",
+        "Bio.PDB.Vector",
+        'Bio.phenotype',
+        'Bio.phenotype.parse',
+        'Bio.phenotype.phen_micro',
+        "Bio.phenotype.pm_fitting",
         "Bio.SeqIO.PdbIO",
         "Bio.Statistics.lowess",
         "Bio.SVDSuperimposer",
@@ -170,12 +145,29 @@ try:
     del sqlite3
 except ImportError:
     # Missing on Jython or Python 2.4
-    DOCTEST_MODULES.remove("Bio.SeqIO")
-    DOCTEST_MODULES.remove("Bio.SearchIO")
+    EXCLUDE_DOCTEST_MODULES.append("Bio.SeqIO")
+    EXCLUDE_DOCTEST_MODULES.append("Bio.SearchIO")
 
-# Skip Bio.Seq doctest under Python 3, see http://bugs.python.org/issue7490
-if sys.version_info[0] == 3:
-    DOCTEST_MODULES.remove("Bio.Seq")
+# Skip Bio.Seq doctest under Python 2, see http://bugs.python.org/issue7490
+# Can't easily write exceptions with consistent class name in python 2 and 3
+if sys.version_info[0] == 2:
+    EXCLUDE_DOCTEST_MODULES.append("Bio.Seq")
+
+
+def find_modules(path):
+    modules = set()
+    for pkg in find_packages(path):
+        modules.add(pkg)
+        pkgpath = path + '/' + pkg.replace('.', '/')
+        if sys.version_info < (3, 6):
+            for _, name, ispkg in iter_modules([pkgpath]):
+                if not ispkg:
+                    modules.add(pkg + '.' + name)
+        else:
+            for info in iter_modules([pkgpath]):
+                if not info.ispkg:
+                    modules.add(pkg + '.' + info.name)
+    return modules
 
 
 # Skip Bio.bgzf doctest for broken gzip, see http://bugs.python.org/issue17666
@@ -208,7 +200,7 @@ def _have_bug17666():
 
 
 if _have_bug17666():
-    DOCTEST_MODULES.remove("Bio.bgzf")
+    EXCLUDE_DOCTEST_MODULES.append("Bio.bgzf")
 
 SYSTEM_LANG = os.environ.get('LANG', 'C')  # Cache this
 
@@ -255,6 +247,7 @@ def main(argv):
             return 0
         if opt == "--offline":
             print("Skipping any tests requiring internet access")
+            EXCLUDE_DOCTEST_MODULES.extend(ONLINE_DOCTEST_MODULES)
             # This is a bit of a hack...
             import requires_internet
             requires_internet.check.available = False
@@ -265,22 +258,6 @@ def main(argv):
                 raise RuntimeError("Internal test suite error, attempting to use internet despite --offline setting")
 
             Bio._py3k.urlopen = dummy_urlopen
-        if opt == "-g" or opt == "--generate":
-            if len(args) > 1:
-                print("Only one argument (the test name) needed for generate")
-                print(__doc__)
-                return 2
-            elif len(args) == 0:
-                print("No test name specified to generate output for.")
-                print(__doc__)
-                return 2
-            # strip off .py if it was included
-            if args[0][-3:] == ".py":
-                args[0] = args[0][:-3]
-
-            test = ComparisonTestCase(args[0])
-            test.generate_output()
-            return 0
 
         if opt == "-v" or opt == "--verbose":
             verbosity = 2
@@ -299,109 +276,6 @@ def main(argv):
     return runner.run()
 
 
-class ComparisonTestCase(unittest.TestCase):
-    """Run a print-and-compare test and check it against expected output."""
-
-    def __init__(self, name, output=None):
-        """Initialize with the test to run.
-
-        Arguments:
-            - name - The name of the test. The expected output should be
-              stored in the file output/name.
-            - output - The output that was generated when this test was run.
-
-        """
-        unittest.TestCase.__init__(self)
-        self.name = name
-        self.output = output
-
-    def shortDescription(self):
-        return self.name
-
-    def runTest(self):
-        # check the expected output to be consistent with what
-        # we generated
-        outputdir = os.path.join(TestRunner.testdir, "output")
-        outputfile = os.path.join(outputdir, self.name)
-        try:
-            if sys.version_info[0] >= 3:
-                # Python 3 problem: Can't use utf8 on output/test_geo
-                # due to micro (\xb5) and degrees (\xb0) symbols
-                # Also universal new lines mode deprecated on Python 3
-                expected = open(outputfile, encoding="latin")
-            else:
-                expected = open(outputfile, "rU")
-        except IOError:
-            self.fail("Warning: Can't open %s for test %s" %
-                      (outputfile, self.name))
-
-        self.output.seek(0)
-        # first check that we are dealing with the right output
-        # the first line of the output file is the test name
-        expected_test = expected.readline().strip()
-
-        if expected_test != self.name:
-            expected.close()
-            raise ValueError("\nOutput:   %s\nExpected: %s"
-                             % (self.name, expected_test))
-
-        # Track the line number. Starts at 1 to account for the output file
-        # header line.
-        line_number = 1
-
-        # now loop through the output and compare it to the expected file
-        while True:
-            expected_line = expected.readline()
-            output_line = self.output.readline()
-            line_number += 1
-
-            # stop looping if either of the info handles reach the end
-            if (not expected_line) or (not output_line):
-                # make sure both have no information left
-                assert expected_line == '', "Unread: %s" % expected_line
-                assert output_line == '', "Extra output: %s" % output_line
-                break
-
-            # normalize the newlines in the two lines
-            expected_line = expected_line.strip("\r\n")
-            output_line = output_line.strip("\r\n")
-
-            # if the line is a doctest or PyUnit time output like:
-            # Ran 2 tests in 0.285s
-            # ignore it, so we don't have problems with different running times
-            if re.compile("^Ran [0-9]+ tests? in ").match(expected_line):
-                pass
-            # otherwise make sure the two lines are the same
-            elif expected_line != output_line:
-                expected.close()
-                raise ValueError("\nOutput  : %s\nExpected: %s\n%s line %s"
-                                 % (repr(output_line), repr(expected_line),
-                                    outputfile, line_number))
-
-        expected.close()
-
-    def generate_output(self):
-        """Generate the golden output for the specified test."""
-        outputdir = os.path.join(TestRunner.testdir, "output")
-        outputfile = os.path.join(outputdir, self.name)
-
-        output_handle = open(outputfile, 'w')
-
-        # write the test name as the first line of the output
-        output_handle.write(self.name + "\n")
-
-        # remember standard out so we can reset it after we are done
-        save_stdout = sys.stdout
-        try:
-            # write the output from the test into a string
-            sys.stdout = output_handle
-            __import__(self.name)
-        finally:
-            output_handle.close()
-            # return standard out to its normal setting
-            sys.stdout = save_stdout
-
-
 class TestRunner(unittest.TextTestRunner):
 
     if __name__ == '__main__':
@@ -432,12 +306,15 @@ class TestRunner(unittest.TextTestRunner):
             self.tests.append("doctest")
         if "doctest" in self.tests:
             self.tests.remove("doctest")
-            self.tests.extend(DOCTEST_MODULES)
+            modules = find_modules(self.testdir + '/..')
+            modules.difference_update(set(EXCLUDE_DOCTEST_MODULES))
+            self.tests.extend(sorted(list(modules)))
         stream = StringIO()
         unittest.TextTestRunner.__init__(self, stream,
                                          verbosity=verbosity)
 
     def runTest(self, name):
+        from Bio import MissingPythonDependencyError
         from Bio import MissingExternalDependencyError
         result = self._makeResult()
         output = StringIO()
@@ -452,8 +329,8 @@ class TestRunner(unittest.TextTestRunner):
             stdout = sys.stdout
             sys.stdout = output
             if name.startswith("test_"):
+                # It's a unittest
                 sys.stderr.write("%s ... " % name)
-                # It's either a unittest or a print-and-compare test
                 loader = unittest.TestLoader()
                 suite = loader.loadTestsFromName(name)
                 if hasattr(loader, "errors") and loader.errors:
@@ -473,14 +350,20 @@ class TestRunner(unittest.TextTestRunner):
                         sys.stderr.write("%s\n" % msg)
                     return False
                 if suite.countTestCases() == 0:
-                    # This is a print-and-compare test instead of a
-                    # unittest-type test.
-                    test = ComparisonTestCase(name, output)
-                    suite = unittest.TestSuite([test])
+                    raise RuntimeError("No tests found in %s" % name)
             else:
                 # It's a doc test
                 sys.stderr.write("%s docstring test ... " % name)
-                module = __import__(name, fromlist=name.split("."))
+                try:
+                    module = __import__(name, fromlist=name.split("."))
+                except MissingPythonDependencyError:
+                    sys.stderr.write("skipped, missing Python dependency\n")
+                    return True
+                except ImportError as e:
+                    sys.stderr.write("FAIL, ImportError\n")
+                    result.stream.write("ERROR while importing %s: %s\n" % (name, e))
+                    result.printErrors()
+                    return False
                 suite = doctest.DocTestSuite(module,
                                              optionflags=doctest.ELLIPSIS)
                 del module
