@@ -2,6 +2,8 @@
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 
+"""Common code for SeqRecord object tests."""
+
 from Bio._py3k import range
 from Bio._py3k import basestring
 
@@ -13,31 +15,32 @@ from Bio.SeqRecord import SeqRecord
 
 
 def checksum_summary(record):
+    """Abbreviated string showing sequence, checksum, and length."""
     if isinstance(record.seq, UnknownSeq):
         return repr(record.seq)
     if len(record.seq) < 25:
         short = str(record.seq)
     else:
         short = str(record.seq)[:19] \
-              + "..." + str(record.seq)[-3:]
+            + "..." + str(record.seq)[-3:]
     return "%s [%s] len %i" \
-           % (short, seguid(record.seq), len(record.seq))
+        % (short, seguid(record.seq), len(record.seq))
 
 
 def compare_reference(old_r, new_r):
-    """Compare two Reference objects
+    """Compare two Reference objects.
 
     Note new_r is assumed to be a BioSQL DBSeqRecord, due to limitations
     of the BioSQL table structure.
     """
     assert old_r.title == new_r.title, \
-           "%s vs %s" % (old_r.title, new_r.title)
+        "%s vs %s" % (old_r.title, new_r.title)
     assert old_r.authors == new_r.authors, \
-           "%s vs %s" % (old_r.authors, new_r.authors)
+        "%s vs %s" % (old_r.authors, new_r.authors)
     assert old_r.journal == new_r.journal, \
-           "%s vs %s" % (old_r.journal, new_r.journal)
+        "%s vs %s" % (old_r.journal, new_r.journal)
     assert old_r.medline_id == new_r.medline_id, \
-           "%s vs %s" % (old_r.medline_id, new_r.medline_id)
+        "%s vs %s" % (old_r.medline_id, new_r.medline_id)
 
     if old_r.pubmed_id and new_r.pubmed_id:
         assert old_r.pubmed_id == new_r.pubmed_id
@@ -50,7 +53,7 @@ def compare_reference(old_r, new_r):
     # Looking at the tables, I *think* the current schema does not
     # allow us to store a reference comment.  Must confirm this.
     assert old_r.comment == new_r.comment or new_r.comment == "", \
-                          "%r vs %r" % (old_r.comment, new_r.comment)
+        "%r vs %r" % (old_r.comment, new_r.comment)
 
     # TODO - assert old_r.consrtm == new_r.consrtm
     # Looking at the tables, I *think* the current schema does not
@@ -65,13 +68,13 @@ def compare_reference(old_r, new_r):
         assert isinstance(old_r.location[0], FeatureLocation)
         assert isinstance(new_r.location[0], FeatureLocation)
         assert old_r.location[0].start == new_r.location[0].start and \
-               old_r.location[0].end == new_r.location[0].end
+            old_r.location[0].end == new_r.location[0].end
 
     return True
 
 
 def compare_feature(old_f, new_f):
-    """Compare two SeqFeature objects"""
+    """Compare two SeqFeature objects."""
     assert isinstance(old_f, SeqFeature)
     assert isinstance(new_f, SeqFeature)
 
@@ -97,18 +100,18 @@ def compare_feature(old_f, new_f):
 
     # We dont store fuzzy locations:
     assert old_f.location.start == new_f.location.start \
-    or (isinstance(old_f.location.start, UnknownPosition) and
-        isinstance(new_f.location.start, UnknownPosition)), \
-               "%s -> %s" % (old_f.location.start,
-                             new_f.location.start)
+        or (isinstance(old_f.location.start, UnknownPosition) and
+            isinstance(new_f.location.start, UnknownPosition)), \
+        "%s -> %s" % (old_f.location.start,
+                      new_f.location.start)
     assert old_f.location.end == new_f.location.end \
-    or (isinstance(old_f.location.end, UnknownPosition) and
-        isinstance(new_f.location.end, UnknownPosition)), \
-               "%s -> %s" % (old_f.location.end,
-                             new_f.location.end)
+        or (isinstance(old_f.location.end, UnknownPosition) and
+            isinstance(new_f.location.end, UnknownPosition)), \
+        "%s -> %s" % (old_f.location.end,
+                      new_f.location.end)
 
     assert isinstance(old_f.location, CompoundLocation) == \
-           isinstance(new_f.location, CompoundLocation)
+        isinstance(new_f.location, CompoundLocation)
     if isinstance(old_f.location, CompoundLocation):
         assert len(old_f.location.parts) == len(new_f.location.parts)
         for old_l, new_l in zip(old_f.location.parts, new_f.location.parts):
@@ -125,56 +128,6 @@ def compare_feature(old_f, new_f):
         assert old_sub.nofuzzy_end == new_sub.nofuzzy_end
         assert old_sub.strand == new_sub.strand
 
-    # Using private variable to avoid deprecation warnings
-    assert len(old_f._sub_features) == len(new_f._sub_features), \
-        "number of sub_features: %s -> %s" % \
-        (len(old_f._sub_features), len(new_f._sub_features))
-
-    for old_sub, new_sub in zip(old_f._sub_features, new_f._sub_features):
-        # These are SeqFeature objects
-        assert old_sub.type == new_sub.type, \
-            "%s -> %s" % (old_sub.type, new_sub.type)
-
-        assert old_sub.strand == new_sub.strand, \
-            "%s -> %s" % (old_sub.strand, new_sub.strand)
-
-        assert old_sub.ref == new_sub.ref, \
-            "%s -> %s" % (old_sub.ref, new_sub.ref)
-
-        assert old_sub.ref_db == new_sub.ref_db, \
-            "%s -> %s" % (old_sub.ref_db, new_sub.ref_db)
-
-        # TODO - Work out how the location_qualifier_value table should
-        # be used, given BioPerl seems to ignore it (Bug 2766)
-        # assert old_sub.location_operator == new_sub.location_operator, \
-        #    "%s -> %s" % (old_sub.location_operator, new_sub.location_operator)
-
-        # Compare sub-feature Locations:
-        #
-        # BioSQL currently does not store fuzzy locations, but instead stores
-        # them as FeatureLocation.nofuzzy_start FeatureLocation.nofuzzy_end.
-        # The vast majority of cases will be comparisons of ExactPosition
-        # class locations, so we'll try that first and catch the exceptions.
-
-        try:
-            assert str(old_sub.location) == str(new_sub.location), \
-               "%s -> %s" % (str(old_sub.location), str(new_sub.location))
-        except AssertionError as e:
-            if isinstance(old_sub.location.start, ExactPosition) and \
-               isinstance(old_sub.location.end, ExactPosition):
-                # Its not a problem with fuzzy locations, re-raise
-                raise e
-            else:
-                # At least one of the locations is fuzzy
-                assert old_sub.location.nofuzzy_start == \
-                       new_sub.location.nofuzzy_start, \
-                       "%s -> %s" % (old_sub.location.nofuzzy_start,
-                                     new_sub.location.nofuzzy_start)
-                assert old_sub.location.nofuzzy_end == \
-                       new_sub.location.nofuzzy_end, \
-                       "%s -> %s" % (old_sub.location.nofuzzy_end,
-                                     new_sub.location.nofuzzy_end)
-
     assert len(old_f.qualifiers) == len(new_f.qualifiers)
     assert set(old_f.qualifiers) == set(new_f.qualifiers)
     for key in old_f.qualifiers:
@@ -184,11 +137,10 @@ def compare_feature(old_f, new_f):
             elif isinstance(new_f.qualifiers[key], list):
                 # Maybe a string turning into a list of strings?
                 assert [old_f.qualifiers[key]] == new_f.qualifiers[key], \
-                        "%s -> %s" \
-                        % (repr(old_f.qualifiers[key]),
-                           repr(new_f.qualifiers[key]))
+                    "%s -> %s" % (repr(old_f.qualifiers[key]),
+                                  repr(new_f.qualifiers[key]))
             else:
-                assert False, "Problem with feature's '%s' qualifier" % key
+                raise ValueError("Problem with feature's '%s' qualifier" % key)
         else:
             # Should both be lists of strings...
             assert old_f.qualifiers[key] == new_f.qualifiers[key], \
@@ -197,9 +149,9 @@ def compare_feature(old_f, new_f):
 
 
 def compare_sequence(old, new):
-    """Compare two Seq or DBSeq objects"""
+    """Compare two Seq or DBSeq objects."""
     assert len(old) == len(new), "%i vs %i" % (len(old), len(new))
-    assert str(old) == str(new)
+    assert str(old) == str(new), "%s vs %s" % (old, new)
 
     if isinstance(old, UnknownSeq):
         assert isinstance(new, UnknownSeq)
@@ -232,9 +184,9 @@ def compare_sequence(old, new):
         for j in indices:
             expected = s[i:j]
             assert expected == str(old[i:j]), \
-                   "Slice %s vs %s" % (repr(expected), repr(old[i:j]))
+                "Slice %s vs %s" % (repr(expected), repr(old[i:j]))
             assert expected == str(new[i:j]), \
-                   "Slice %s vs %s" % (repr(expected), repr(new[i:j]))
+                "Slice %s vs %s" % (repr(expected), repr(new[i:j]))
             # Slicing with step of 1 should make no difference.
             # Slicing with step 3 might be useful for codons.
             for step in [1, 3]:
@@ -258,6 +210,7 @@ def compare_sequence(old, new):
 
 
 def compare_features(old_list, new_list):
+    """Compare two lists of SeqFeature objects."""
     assert isinstance(old_list, list)
     assert isinstance(new_list, list)
     assert len(old_list) == len(new_list)
@@ -268,7 +221,7 @@ def compare_features(old_list, new_list):
 
 
 def compare_record(old, new):
-    """Compare two SeqRecord or DBSeqRecord objects"""
+    """Compare two SeqRecord or DBSeqRecord objects."""
     assert isinstance(old, SeqRecord)
     assert isinstance(new, SeqRecord)
     # Sequence:
@@ -278,8 +231,8 @@ def compare_record(old, new):
     assert old.name == new.name
     assert old.description == new.description
     assert old.dbxrefs == new.dbxrefs, \
-           "dbxrefs mismatch\nOld: %s\nNew: %s" \
-           % (old.dbxrefs, new.dbxrefs)
+        "dbxrefs mismatch\nOld: %s\nNew: %s" \
+        % (old.dbxrefs, new.dbxrefs)
     # Features:
     if not compare_features(old.features, new.features):
         return False
@@ -291,15 +244,15 @@ def compare_record(old, new):
     # TODO - address these, see Bug 2681?
     new_keys = set(new.annotations).difference(old.annotations)
     new_keys = new_keys.difference(['cross_references', 'date',
-                                    'data_file_division', 'ncbi_taxid', 
+                                    'data_file_division', 'ncbi_taxid',
                                     'gi'])
     assert not new_keys, "Unexpected new annotation keys: %s" \
-           % ", ".join(new_keys)
+        % ", ".join(new_keys)
     missing_keys = set(old.annotations).difference(new.annotations)
     missing_keys = missing_keys.difference(['ncbi_taxid',  # Can't store chimeras
                                             'structured_comment'])
     assert not missing_keys, "Unexpectedly missing annotation keys: %s" \
-           % ", ".join(missing_keys)
+        % ", ".join(missing_keys)
 
     # In the short term, just compare any shared keys:
     for key in set(old.annotations).intersection(new.annotations):
@@ -331,19 +284,19 @@ def compare_record(old, new):
             # guarantee that they will be identical after a load/retrieve.
             assert isinstance(new.annotations[key], basestring) \
                 or isinstance(new.annotations[key], list)
-        elif type(old.annotations[key]) == type(new.annotations[key]):
+        elif isinstance(old.annotations[key], type(new.annotations[key])):
             assert old.annotations[key] == new.annotations[key], \
                 "Annotation '%s' changed by load/retrieve\nWas:%s\nNow:%s" \
                 % (key, old.annotations[key], new.annotations[key])
-        elif isinstance(old.annotations[key], str) \
-        and isinstance(new.annotations[key], list):
+        elif (isinstance(old.annotations[key], str)
+              and isinstance(new.annotations[key], list)):
             # Any annotation which is a single string gets turned into
             # a list containing one string by BioSQL at the moment.
             assert [old.annotations[key]] == new.annotations[key], \
                 "Annotation '%s' changed by load/retrieve\nWas:%s\nNow:%s" \
                 % (key, old.annotations[key], new.annotations[key])
-        elif isinstance(old.annotations[key], list) \
-        and isinstance(new.annotations[key], str):
+        elif (isinstance(old.annotations[key], list)
+              and isinstance(new.annotations[key], str)):
             assert old.annotations[key] == [new.annotations[key]], \
                 "Annotation '%s' changed by load/retrieve\nWas:%s\nNow:%s" \
                 % (key, old.annotations[key], new.annotations[key])
@@ -351,6 +304,7 @@ def compare_record(old, new):
 
 
 def compare_records(old_list, new_list):
+    """Compare two lists of SeqRecord objects."""
     assert isinstance(old_list, list)
     assert isinstance(new_list, list)
     assert len(old_list) == len(new_list)
