@@ -28,7 +28,7 @@ os.environ['LANG'] = 'C'
 
 exes_wanted = ["water", "needle", "seqret", "transeq", "seqmatchall",
                "embossversion"]
-exes = dict()  # Dictionary mapping from names to exe locations
+exes = {}  # Dictionary mapping from names to exe locations
 
 if "EMBOSS_ROOT" in os.environ:
     # Windows default installation path is C:\mEMBOSS which contains the exes.
@@ -41,7 +41,7 @@ if "EMBOSS_ROOT" in os.environ:
         del name
     else:
         raise MissingExternalDependencyError(
-                  "$EMBOSS_ROOT=%r which does not exist!" % path)
+            "$EMBOSS_ROOT=%r which does not exist!" % path)
     del path
 if sys.platform != "win32":
     from Bio._py3k import getoutput
@@ -59,7 +59,7 @@ if len(exes) < len(exes_wanted):
 
 
 def get_emboss_version():
-    """Returns a tuple of three ints, e.g. (6,1,0)"""
+    """Return a tuple of three ints, e.g. (6,1,0)."""
     # Windows and Unix versions of EMBOSS seem to differ in
     # which lines go to stdout and stderr - so merge them.
     child = subprocess.Popen(_escape_filename(exes["embossversion"]),
@@ -206,9 +206,11 @@ def compare_records(old_list, new_list):
     for old, new in zip(old_list, new_list):
         # Note the name matching is a bit fuzzy, e.g. truncation and
         # no spaces in PHYLIP files.
-        if old.id != new.id and old.name != new.name \
-        and (old.id not in new.id) and (new.id not in old.id) \
-        and (old.id.replace(" ", "_") != new.id.replace(" ", "_")):
+        if (old.id != new.id and
+                old.name != new.name and
+                (old.id not in new.id) and
+                (new.id not in old.id) and
+                (old.id.replace(" ", "_") != new.id.replace(" ", "_"))):
             raise ValueError("'%s' or '%s' vs '%s' or '%s' records"
                              % (old.id, old.name, new.id, new.name))
         if len(old.seq) != len(new.seq):
@@ -223,7 +225,7 @@ def compare_records(old_list, new_list):
                                  % (old.seq[:60], old.seq[-10:],
                                     new.seq[:60], new.seq[-10:]))
         if old.features and new.features \
-        and len(old.features) != len(new.features):
+           and len(old.features) != len(new.features):
             raise ValueError("%i vs %i features"
                              % (len(old.features), len(new.features)))
         # TODO - check annotation
@@ -251,7 +253,7 @@ class SeqRetSeqIOTests(unittest.TestCase):
 
     def check_SeqIO_to_EMBOSS(self, in_filename, in_format, skip_formats=(),
                               alphabet=None):
-        """Can Bio.SeqIO write files seqret can read back?"""
+        """Check SeqIO writes files seqret can read back."""
         if alphabet:
             records = list(SeqIO.parse(in_filename, in_format, alphabet))
         else:
@@ -268,7 +270,7 @@ class SeqRetSeqIOTests(unittest.TestCase):
 
     def check_EMBOSS_to_SeqIO(self, filename, old_format,
                               skip_formats=()):
-        """Can Bio.SeqIO read seqret's conversion of the file?"""
+        """Check SeqIO can read read seqret's conversion output."""
         # TODO: Why can't we read EMBOSS's swiss output?
         self.assertTrue(os.path.isfile(filename))
         old_records = list(SeqIO.parse(filename, old_format))
@@ -340,18 +342,18 @@ class SeqRetSeqIOTests(unittest.TestCase):
         """Check SeqIO & EMBOSS reading each other's conversions of a PIR file."""
         # Skip genbank here, EMBOSS mangles the LOCUS line:
         self.check_SeqIO_with_EMBOSS("NBRF/clustalw.pir", "pir",
-                               skip_formats=["genbank"])
+                                     skip_formats=["genbank"])
         # Skip EMBL here, EMBOSS mangles the ID line
         # Skip GenBank, EMBOSS 6.0.1 on Windows won't output proteins as GenBank
         self.check_SeqIO_with_EMBOSS("NBRF/DMB_prot.pir", "pir",
-                               skip_formats=["embl", "genbank"])
+                                     skip_formats=["embl", "genbank"])
 
     def test_clustalw(self):
         """Check SeqIO & EMBOSS reading each other's conversions of a Clustalw file."""
         self.check_SeqIO_with_EMBOSS("Clustalw/hedgehog.aln", "clustal",
-                                   skip_formats=["embl", "genbank"])
+                                     skip_formats=["embl", "genbank"])
         self.check_SeqIO_with_EMBOSS("Clustalw/opuntia.aln", "clustal",
-                                   skip_formats=["embl", "genbank"])
+                                     skip_formats=["embl", "genbank"])
 
 
 class SeqRetAlignIOTests(unittest.TestCase):
@@ -361,8 +363,8 @@ class SeqRetAlignIOTests(unittest.TestCase):
         clean_up()
 
     def check_EMBOSS_to_AlignIO(self, filename, old_format,
-                              skip_formats=()):
-        """Can AlignIO read seqret's conversion of the file?"""
+                                skip_formats=()):
+        """Check AlignIO can read seqret's conversion of the file."""
         self.assertTrue(os.path.isfile(filename), filename)
         old_aligns = list(AlignIO.parse(filename, old_format))
         formats = ["clustal", "phylip", "ig"]
@@ -387,7 +389,7 @@ class SeqRetAlignIOTests(unittest.TestCase):
 
     def check_AlignIO_to_EMBOSS(self, in_filename, in_format, skip_formats=(),
                                 alphabet=None):
-        """Can Bio.AlignIO write files seqret can read back?"""
+        """Check Bio.AlignIO can write files seqret can read."""
         if alphabet:
             old_aligns = list(AlignIO.parse(in_filename, in_format, alphabet))
         else:
@@ -428,7 +430,7 @@ class SeqRetAlignIOTests(unittest.TestCase):
         self.check_AlignIO_with_EMBOSS("Clustalw/hedgehog.aln", "clustal")
         self.check_AlignIO_with_EMBOSS("Clustalw/opuntia.aln", "clustal")
         self.check_AlignIO_with_EMBOSS("Clustalw/odd_consensus.aln", "clustal",
-                               skip_formats=["nexus"])  # TODO - why not nexus?
+                                       skip_formats=["nexus"])  # TODO - why not nexus?
         self.check_AlignIO_with_EMBOSS("Clustalw/protein.aln", "clustal")
         self.check_AlignIO_with_EMBOSS("Clustalw/promals3d.aln", "clustal")
 
@@ -461,15 +463,15 @@ class PairwiseAlignmentTests(unittest.TestCase):
             self.assertEqual(len(alignment), 2)
             # self.assertEqual(target.id, alignment[1].id) #too strict
             if alignment[1].id not in target.id \
-            and alignment[1].id not in target.name:
+               and alignment[1].id not in target.name:
                 raise AssertionError("%s vs %s or %s"
                                      % (alignment[1].id, target.id, target.name))
             if local:
                 # Local alignment
                 self.assertTrue(str(alignment[0].seq).replace("-", "")
-                             in query_seq)
+                                in query_seq)
                 self.assertTrue(str(alignment[1].seq).replace("-", "").upper()
-                             in str(target.seq).upper())
+                                in str(target.seq).upper())
             else:
                 # Global alignment
                 self.assertEqual(str(query_seq), str(alignment[0].seq).replace("-", ""))
@@ -574,11 +576,11 @@ class PairwiseAlignmentTests(unittest.TestCase):
     def test_needle_piped(self):
         """Run needle with asis trick, output piped to stdout."""
         cline = NeedleCommandline(cmd=exes["needle"],
-                                 asequence="asis:ACCCGGGCGCGGT",
-                                 bsequence="asis:ACCCGAGCGCGGT",
-                                 gapopen=10,
-                                 gapextend=0.5,
-                                 auto=True, filter=True)
+                                  asequence="asis:ACCCGGGCGCGGT",
+                                  bsequence="asis:ACCCGAGCGCGGT",
+                                  gapopen=10,
+                                  gapextend=0.5,
+                                  auto=True, filter=True)
         self.assertEqual(str(cline),
                          exes["needle"] + " -auto -filter" +
                          " -asequence=asis:ACCCGGGCGCGGT" +
@@ -732,11 +734,11 @@ class PairwiseAlignmentTests(unittest.TestCase):
     def test_needle_needs_output(self):
         """Run needle without output file or stdout/filter should give error."""
         cline = NeedleCommandline(cmd=exes["needle"],
-                                 asequence="asis:ACCCGGGCGCGGT",
-                                 bsequence="asis:ACCCGAGCGCGGT",
-                                 gapopen=10,
-                                 gapextend=0.5,
-                                 auto=True)
+                                  asequence="asis:ACCCGGGCGCGGT",
+                                  bsequence="asis:ACCCGAGCGCGGT",
+                                  gapopen=10,
+                                  gapextend=0.5,
+                                  auto=True)
         self.assertTrue(cline.auto)
         self.assertTrue(not cline.stdout)
         self.assertTrue(not cline.filter)
@@ -835,14 +837,14 @@ def check_translation(sequence, translation, table=None):
     else:
         t = table
     if translation != str(sequence.translate(t)) \
-    or translation != str(translate(sequence, t)) \
-    or translation != translate(str(sequence), t):
+       or translation != str(translate(sequence, t)) \
+       or translation != translate(str(sequence), t):
         # More details...
         for i, amino in enumerate(translation):
             codon = sequence[i * 3:i * 3 + 3]
             if amino != str(codon.translate(t)):
                 raise ValueError("%s -> %s not %s (table %s)"
-                         % (codon, amino, codon.translate(t), t))
+                                 % (codon, amino, codon.translate(t), t))
         # Shouldn't reach this line:
         raise ValueError("%s -> %s (table %s)"
                          % (sequence, translation, t))
@@ -857,7 +859,6 @@ class TranslationTests(unittest.TestCase):
 
     def test_simple(self):
         """Run transeq vs Bio.Seq for simple translations (including alt tables)."""
-
         examples = [Seq("ACGTGACTGACGTAGCATGCCACTAGG"),
                     # Unamibguous TA? codons:
                     Seq("TAATACTATTAG", generic_dna),
