@@ -4,15 +4,18 @@
 # as part of this package.
 #
 # This unit test attempts to locate the blastall executable and the nr
-# database, and if it finds them then do some standalone blast searches
-# using Bio.Blast.NCBIStandalone to call the command line tool.
+# database.
+
+"""Tests for NCBI BLAST tools module."""
 
 from __future__ import print_function
 
 import os
+import os.path
 import sys
 import subprocess
 import unittest
+import re
 
 from Bio.Application import _escape_filename
 from Bio import MissingExternalDependencyError
@@ -22,7 +25,7 @@ from Bio.Blast import Applications
 wanted = ["blastx", "blastp", "blastn", "tblastn", "tblastx",
           "rpsblast+",  # For Debian
           "rpsblast", "rpstblastn", "psiblast", "blast_formatter",
-          "deltablast"]
+          "deltablast", "makeblastdb"]
 exe_names = {}
 
 if sys.platform == "win32":
@@ -85,12 +88,13 @@ if len(set(exe_names).difference(optional)) < len(set(wanted).difference(optiona
 
 class Pairwise(unittest.TestCase):
     def test_blastp(self):
-        """Pairwise BLASTP search"""
+        """Pairwise BLASTP search."""
         global exe_names
-        cline = Applications.NcbiblastpCommandline(exe_names["blastp"],
-                        query="Fasta/rose.pro",
-                        subject="GenBank/NC_005816.faa",
-                        evalue=1)
+        cline = Applications.NcbiblastpCommandline(
+            exe_names["blastp"],
+            query="Fasta/rose.pro",
+            subject="GenBank/NC_005816.faa",
+            evalue=1)
         self.assertEqual(str(cline), _escape_filename(exe_names["blastp"]) +
                          " -query Fasta/rose.pro -evalue 1" +
                          " -subject GenBank/NC_005816.faa")
@@ -116,17 +120,14 @@ class Pairwise(unittest.TestCase):
             self.assertEqual(1, stdoutdata.count("Query= "))
             self.assertEqual(0, stdoutdata.count("***** No hits found *****"))
 
-        # TODO - Parse it? I think we'd need to update this obsole code :(
-        # records = list(NCBIStandalone.Iterator(StringIO(stdoutdata),
-        #                                       NCBIStandalone.BlastParser()))
-
     def test_blastn(self):
-        """Pairwise BLASTN search"""
+        """Pairwise BLASTN search."""
         global exe_names
-        cline = Applications.NcbiblastnCommandline(exe_names["blastn"],
-                        query="GenBank/NC_005816.ffn",
-                        subject="GenBank/NC_005816.fna",
-                        evalue="0.000001")
+        cline = Applications.NcbiblastnCommandline(
+            exe_names["blastn"],
+            query="GenBank/NC_005816.ffn",
+            subject="GenBank/NC_005816.fna",
+            evalue="0.000001")
         self.assertEqual(str(cline), _escape_filename(exe_names["blastn"]) +
                          " -query GenBank/NC_005816.ffn -evalue 0.000001" +
                          " -subject GenBank/NC_005816.fna")
@@ -144,12 +145,13 @@ class Pairwise(unittest.TestCase):
         # TODO - Parse it?
 
     def test_tblastn(self):
-        """Pairwise TBLASTN search"""
+        """Pairwise TBLASTN search."""
         global exe_names
-        cline = Applications.NcbitblastnCommandline(exe_names["tblastn"],
-                        query="GenBank/NC_005816.faa",
-                        subject="GenBank/NC_005816.fna",
-                        evalue="1e-6")
+        cline = Applications.NcbitblastnCommandline(
+            exe_names["tblastn"],
+            query="GenBank/NC_005816.faa",
+            subject="GenBank/NC_005816.fna",
+            evalue="1e-6")
         self.assertEqual(str(cline), _escape_filename(exe_names["tblastn"]) +
                          " -query GenBank/NC_005816.faa -evalue 1e-6" +
                          " -subject GenBank/NC_005816.fna")
@@ -167,14 +169,112 @@ class Pairwise(unittest.TestCase):
         # TODO - Parse it?
 
 
+class BlastDB(unittest.TestCase):
+    def test_requires_dbtype(self):
+        """Check that dbtype throws error if not set."""
+        global exe_names
+        cline = Applications.NcbimakeblastdbCommandline(
+            exe_names["makeblastdb"],
+            input_file="GenBank/NC_005816.faa")
+        with self.assertRaises(ValueError):
+            str(cline)
+
+    def test_fasta_db_prot(self):
+        """Test makeblastdb wrapper with protein database."""
+        global exe_names
+        cline = Applications.NcbimakeblastdbCommandline(
+            exe_names["makeblastdb"],
+            input_file="GenBank/NC_005816.faa",
+            dbtype="prot",
+            hash_index=True,
+            max_file_sz="20MB",
+            parse_seqids=True,
+            taxid=10)
+
+        self.assertEqual(str(cline),
+                         _escape_filename(exe_names["makeblastdb"]) +
+                         " -dbtype prot -in GenBank/NC_005816.faa"
+                         " -parse_seqids -hash_index -max_file_sz 20MB"
+                         " -taxid 10")
+
+        child = subprocess.Popen(str(cline),
+                                 stdout=subprocess.PIPE,
+                                 stderr=subprocess.PIPE,
+                                 universal_newlines=True,
+                                 shell=(sys.platform != "win32"))
+        stdoutdata, stderrdata = child.communicate()
+        return_code = child.returncode
+
+        self.assertTrue(os.path.isfile("GenBank/NC_005816.faa.phd"))
+        self.assertTrue(os.path.isfile("GenBank/NC_005816.faa.phi"))
+        self.assertTrue(os.path.isfile("GenBank/NC_005816.faa.phr"))
+        self.assertTrue(os.path.isfile("GenBank/NC_005816.faa.pin"))
+        self.assertTrue(os.path.isfile("GenBank/NC_005816.faa.pog"))
+        self.assertTrue(os.path.isfile("GenBank/NC_005816.faa.psd"))
+        self.assertTrue(os.path.isfile("GenBank/NC_005816.faa.psi"))
+        self.assertTrue(os.path.isfile("GenBank/NC_005816.faa.psq"))
+
+    def test_fasta_db_nucl(self):
+        """Test makeblastdb wrapper with nucleotide database."""
+        global exe_names
+        cline = Applications.NcbimakeblastdbCommandline(
+            exe_names["makeblastdb"],
+            input_file="GenBank/NC_005816.fna",
+            dbtype="nucl",
+            hash_index=True,
+            max_file_sz="20MB",
+            parse_seqids=True,
+            taxid=10)
+
+        self.assertEqual(str(cline),
+                         _escape_filename(exe_names["makeblastdb"]) +
+                         " -dbtype nucl -in GenBank/NC_005816.fna"
+                         " -parse_seqids -hash_index -max_file_sz 20MB"
+                         " -taxid 10")
+
+        child = subprocess.Popen(str(cline),
+                                 stdout=subprocess.PIPE,
+                                 stderr=subprocess.PIPE,
+                                 universal_newlines=True,
+                                 shell=(sys.platform != "win32"))
+        stdoutdata, stderrdata = child.communicate()
+        return_code = child.returncode
+
+        self.assertTrue(os.path.isfile("GenBank/NC_005816.fna.nhd"))
+        self.assertTrue(os.path.isfile("GenBank/NC_005816.fna.nhi"))
+        self.assertTrue(os.path.isfile("GenBank/NC_005816.fna.nhr"))
+        self.assertTrue(os.path.isfile("GenBank/NC_005816.fna.nin"))
+        self.assertTrue(os.path.isfile("GenBank/NC_005816.fna.nog"))
+        self.assertTrue(os.path.isfile("GenBank/NC_005816.fna.nsd"))
+        self.assertTrue(os.path.isfile("GenBank/NC_005816.fna.nsi"))
+        self.assertTrue(os.path.isfile("GenBank/NC_005816.fna.nsq"))
+
+    # makeblastdb makes files in the same dir as the input, clean these up
+    def tearDown(self):
+        blastdb_matcher_prot = re.compile(r'NC_005816\.faa\.p.+')
+        for file in os.listdir('GenBank/'):
+            if blastdb_matcher_prot.match(file):
+                path = os.path.join('GenBank/', file)
+                os.remove(path)
+
+        blastdb_matcher_nucl = re.compile(r'NC_005816\.fna\.n.+')
+        for file in os.listdir('GenBank/'):
+            if blastdb_matcher_nucl.match(file):
+                path = os.path.join('GenBank/', file)
+                os.remove(path)
+
+
 class CheckCompleteArgList(unittest.TestCase):
     def check(self, exe_name, wrapper):
         global exe_names
         exe = exe_names[exe_name]
-        cline = wrapper(exe, h=True)
-
-        names = set(parameter.names[0]
-                    for parameter in cline.parameters)
+        # dbtype must be set to initialize NcbimakeblastdbCommandline
+        if exe_name == 'makeblastdb':
+            cline = wrapper(exe, h=True, dbtype='prot')
+        else:
+            cline = wrapper(exe, h=True)
+        names = {parameter.names[0]
+                 for parameter in cline.parameters}
 
         child = subprocess.Popen(str(cline),
                                  stdout=subprocess.PIPE,
@@ -229,7 +329,7 @@ class CheckCompleteArgList(unittest.TestCase):
         if "-seqidlist" in extra:
             extra.remove("-seqidlist")
         if "-db_hard_mask" in extra \
-        and exe_name in ["blastn", "blastp", "blastx", "tblastx", "tblastn"]:
+           and exe_name in ["blastn", "blastp", "blastx", "tblastx", "tblastn"]:
             # New in BLAST 2.2.25+ so will look like an extra arg on old BLAST
             extra.remove("-db_hard_mask")
         if "-msa_master_idx" in extra and exe_name == "psiblast":
@@ -281,6 +381,13 @@ class CheckCompleteArgList(unittest.TestCase):
         if exe_name in ["deltablast", "psiblast"]:
             # New in BLAST+ 2.3.0 so will look like extra args on older verions
             extra = extra.difference(["-save_each_pssm", "-save_pssm_after_last_round"])
+        if exe_name == "makeblastdb":
+            # -input_type is new in BLAST+ 2.2.26+ so will look like extra
+            # arg on older versions. -mask_desc and -mask_id were added after
+            # 2.2.28+, but not documented in changelog.
+            # -dbtype also ignored here, as it was set to initialize class.
+            extra = extra.difference(["-input_type", "-mask_desc",
+                                      "-mask_id", "-dbtype"])
         # This was added in BLAST+ 2.7.1 (or maybe 2.7.0) to most/all the tools,
         # so will be seen as an extra argument on older versions:
         if "-negative_seqidlist" in extra:
@@ -292,8 +399,8 @@ class CheckCompleteArgList(unittest.TestCase):
                           "update Biopython, or report this issue if you are "
                           "already using the latest version. (Extra args: %s; "
                           "Missing: %s)" % (exe_name,
-                          ",".join(sorted(extra)),
-                          ",".join(sorted(missing))))
+                                            ",".join(sorted(extra)),
+                                            ",".join(sorted(missing))))
 
         # An almost trivial example to test any validation
         if "-query" in names:
@@ -303,45 +410,49 @@ class CheckCompleteArgList(unittest.TestCase):
         str(cline)
 
     def test_blastx(self):
-        """Check all blastx arguments are supported"""
+        """Check all blastx arguments are supported."""
         self.check("blastx", Applications.NcbiblastxCommandline)
 
     def test_blastp(self):
-        """Check all blastp arguments are supported"""
+        """Check all blastp arguments are supported."""
         self.check("blastp", Applications.NcbiblastpCommandline)
 
     def test_blastn(self):
-        """Check all blastn arguments are supported"""
+        """Check all blastn arguments are supported."""
         self.check("blastn", Applications.NcbiblastnCommandline)
 
     def test_tblastx(self):
-        """Check all tblastx arguments are supported"""
+        """Check all tblastx arguments are supported."""
         self.check("tblastx", Applications.NcbitblastxCommandline)
 
     def test_tblastn(self):
-        """Check all tblastn arguments are supported"""
+        """Check all tblastn arguments are supported."""
         self.check("tblastn", Applications.NcbitblastnCommandline)
 
     def test_psiblast(self):
-        """Check all psiblast arguments are supported"""
+        """Check all psiblast arguments are supported."""
         self.check("psiblast", Applications.NcbipsiblastCommandline)
 
     def test_rpsblast(self):
-        """Check all rpsblast arguments are supported"""
+        """Check all rpsblast arguments are supported."""
         self.check("rpsblast", Applications.NcbirpsblastCommandline)
 
     def test_rpstblastn(self):
-        """Check all rpstblastn arguments are supported"""
+        """Check all rpstblastn arguments are supported."""
         self.check("rpstblastn", Applications.NcbirpstblastnCommandline)
 
+    def test_makeblastdb(self):
+        """Check all makeblastdb arguments are supported."""
+        self.check("makeblastdb", Applications.NcbimakeblastdbCommandline)
+
     if "blast_formatter" in exe_names:
         def test_blast_formatter(self):
-            """Check all blast_formatter arguments are supported"""
+            """Check all blast_formatter arguments are supported."""
             self.check("blast_formatter", Applications.NcbiblastformatterCommandline)
 
     if "deltablast" in exe_names:
         def test_deltablast(self):
-            """Check all deltablast arguments are supported"""
+            """Check all deltablast arguments are supported."""
             self.check("deltablast", Applications.NcbideltablastCommandline)
 
 
