@@ -25,7 +25,7 @@ try:
     from numpy import dot  # Missing on old PyPy's micronumpy
     del dot
     from numpy.linalg import svd, det  # Missing in PyPy 2.0 numpypy
-    from numpy.random import random
+    del svd, det
 except ImportError:
     from Bio import MissingPythonDependencyError
     raise MissingPythonDependencyError(
@@ -38,7 +38,7 @@ from Bio.PDB import PDBParser, PPBuilder, CaPPBuilder, PDBIO, Select, MMCIFParse
 from Bio.PDB.MMCIF2Dict import MMCIF2Dict
 from Bio.PDB import HSExposureCA, HSExposureCB, ExposureCN
 from Bio.PDB.PDBExceptions import PDBConstructionException, PDBConstructionWarning
-from Bio.PDB import rotmat, Vector, refmat, calc_angle, calc_dihedral, rotaxis, m2rotaxis
+from Bio.PDB import rotmat, Vector
 from Bio.PDB import Residue, Atom
 from Bio.PDB import make_dssp_dict
 from Bio.PDB import DSSP
@@ -80,7 +80,7 @@ class A_ExceptionTest(unittest.TestCase):
                     "Residue (' ', 80, ' ') redefined at line 633.",
                     "Residue (' ', 81, ' ') redefined at line 646.",
                     'Atom O defined twice in residue <Residue HOH het=W resseq=67 icode= > at line 902.'
-                    ]):
+            ]):
                 self.assertIn(msg, str(wrn))
 
     def test_2_strict(self):
@@ -102,7 +102,7 @@ class A_ExceptionTest(unittest.TestCase):
                           parser.get_structure, "example", StringIO(data))
 
     def test_4_occupancy(self):
-        """Parse file with missing occupancy"""
+        """Parse file with missing occupancy."""
         permissive = PDBParser(PERMISSIVE=True)
         with warnings.catch_warnings(record=True) as w:
             warnings.simplefilter("always", PDBConstructionWarning)
@@ -538,16 +538,15 @@ class ParseTest(unittest.TestCase):
             io.save(filename)
             # Check if there are lines besides 'ATOM', 'TER' and 'END'
             with open(filename, 'rU') as handle:
-                record_set = set(l[0:6] for l in handle)
-            record_set -= set(('ATOM  ', 'HETATM', 'MODEL ', 'ENDMDL', 'TER\n',  'TER   ', 'END\n', 'END   '))
+                record_set = {l[0:6] for l in handle}
+            record_set -= {'ATOM  ', 'HETATM', 'MODEL ', 'ENDMDL', 'TER\n', 'TER   ', 'END\n', 'END   '}
             self.assertEqual(record_set, set())
         finally:
             os.remove(filename)
 
     # Tests for sorting methods
     def test_comparison_entities(self):
-        """Test comparing and sorting the several SMCRA objects"""
-
+        """Test comparing and sorting the several SMCRA objects."""
         struct = self.structure
         # Test deepcopy of a structure with disordered atoms
         struct2 = deepcopy(struct)
@@ -569,10 +568,12 @@ class ParseTest(unittest.TestCase):
             len_special = len(special)
             # Placed N, CA, C, O first?
             self.assertEqual(new[:len_special], special,
-                            "Sorted residue did not place N, CA, C, O first: %s" % new)
+                             "Sorted residue did not place N, CA, C, "
+                             "O first: %s" % new)
             # Placed everyone else alphabetically?
             self.assertEqual(new[len_special:], sorted(new[len_special:]),
-                            "After N, CA, C, O order Should be alphabetical: %s" % new)
+                             "After N, CA, C, O order Should be "
+                             "alphabetical: %s" % new)
         # DisorderedResidue
         residues = [r.id[1] for r in sorted(struct[1]['A'])][79:81]
         self.assertEqual(residues, [80, 81])
@@ -672,7 +673,7 @@ class ParseReal(unittest.TestCase):
             self.assertEqual(new[0:special_len], special,
                              "Sorted residue did not place N, CA, C, O first: %s" % new)
             self.assertEqual(new[special_len:], sorted(new[special_len:]),
-                                 "After N, CA, C, O should be alphabet: %s" % new)
+                             "After N, CA, C, O should be alphabet: %s" % new)
 
     def test_c_n(self):
         """Extract polypeptides from 1A80."""
@@ -872,8 +873,11 @@ class WriteTest(unittest.TestCase):
         """Write a full structure using PDBIO."""
         io = PDBIO()
         struct1 = self.structure
+        # Ensure that set_structure doesn't alter parent
+        parent = struct1.parent
         # Write full model to temp file
         io.set_structure(struct1)
+        self.assertIs(parent, struct1.parent)
         filenumber, filename = tempfile.mkstemp()
         os.close(filenumber)
         try:
@@ -886,12 +890,15 @@ class WriteTest(unittest.TestCase):
             os.remove(filename)
 
     def test_pdbio_write_residue(self):
-        """Write a single residue using PDBIO"""
+        """Write a single residue using PDBIO."""
         io = PDBIO()
         struct1 = self.structure
         residue1 = list(struct1.get_residues())[0]
+        # Ensure that set_structure doesn't alter parent
+        parent = residue1.parent
         # Write full model to temp file
         io.set_structure(residue1)
+        self.assertIs(parent, residue1.parent)
         filenumber, filename = tempfile.mkstemp()
         os.close(filenumber)
         try:
@@ -910,8 +917,11 @@ class WriteTest(unittest.TestCase):
         atm = Atom.Atom('CA', [0.1, 0.1, 0.1], 1.0, 1.0, ' ', 'CA', 1, 'C')
         res.add(atm)
 
+        # Ensure that set_structure doesn't alter parent
+        parent = res.parent
         # Write full model to temp file
         io.set_structure(res)
+        self.assertIs(parent, res.parent)
         filenumber, filename = tempfile.mkstemp()
         os.close(filenumber)
         try:
@@ -937,8 +947,11 @@ class WriteTest(unittest.TestCase):
 
         io = PDBIO()
         struct1 = self.structure
+        # Ensure that set_structure doesn't alter parent
+        parent = struct1.parent
         # Write to temp file
         io.set_structure(struct1)
+        self.assertIs(parent, struct1.parent)
         filenumber, filename = tempfile.mkstemp()
         os.close(filenumber)
         try:
@@ -1184,18 +1197,18 @@ class Atom_Element(unittest.TestCase):
             return Atom.Atom(fullname.strip(), None, None, None, None,
                              fullname, None).element
 
-        pdb_elements = dict(
-            H=(' H  ', ' HA ', ' HB ', ' HD1', ' HD2', ' HE ', ' HE1', ' HE2',
-               ' HE3', ' HG ', ' HG1', ' HH ', ' HH2', ' HZ ', ' HZ2', ' HZ3',
-               '1H  ', '1HA ', '1HB ', '1HD ', '1HD1', '1HD2', '1HE ', '1HE2',
-               '1HG ', '1HG1', '1HG2', '1HH1', '1HH2', '1HZ ', '2H  ', '2HA ',
-               '2HB ', '2HD ', '2HD1', '2HD2', '2HE ', '2HE2', '2HG ', '2HG1',
-               '2HG2', '2HH1', '2HH2', '2HZ ', '3H  ', '3HB ', '3HD1', '3HD2',
-               '3HE ', '3HG1', '3HG2', '3HZ ', 'HE21'),
-            O=(' OH ',),  # noqa: E741
-            C=(' CH2',),
-            N=(' NH1', ' NH2'),
-        )
+        pdb_elements = {
+            'H': (' H  ', ' HA ', ' HB ', ' HD1', ' HD2', ' HE ', ' HE1', ' HE2',
+                  ' HE3', ' HG ', ' HG1', ' HH ', ' HH2', ' HZ ', ' HZ2', ' HZ3',
+                  '1H  ', '1HA ', '1HB ', '1HD ', '1HD1', '1HD2', '1HE ', '1HE2',
+                  '1HG ', '1HG1', '1HG2', '1HH1', '1HH2', '1HZ ', '2H  ', '2HA ',
+                  '2HB ', '2HD ', '2HD1', '2HD2', '2HE ', '2HE2', '2HG ', '2HG1',
+                  '2HG2', '2HH1', '2HH2', '2HZ ', '3H  ', '3HB ', '3HD1', '3HD2',
+                  '3HE ', '3HG1', '3HG2', '3HZ ', 'HE21'),
+            'O': (' OH ',),  # noqa: E741
+            'C': (' CH2',),
+            'N': (' NH1', ' NH2')
+        }
 
         for element, atom_names in pdb_elements.items():
             for fullname in atom_names:
@@ -1235,7 +1248,7 @@ class ChangingIdTests(unittest.TestCase):
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", PDBConstructionWarning)
             self.struc = PDBParser(PERMISSIVE=True).get_structure(
-                                                  'X', "PDB/a_structure.pdb")
+                'X', "PDB/a_structure.pdb")
 
     def test_change_model_id(self):
         """Change the id of a model."""
@@ -1264,6 +1277,13 @@ class ChangingIdTests(unittest.TestCase):
         model = next(iter(self.struc))
         self.assertIn("R", model)
 
+    def test_change_id_to_self(self):
+        """Changing the id to itself does nothing (does not raise)."""
+        chain = next(iter(self.struc.get_chains()))
+        chain_id = chain.id
+        chain.id = chain_id
+        self.assertEqual(chain.id, chain_id)
+
     def test_change_residue_id(self):
         """Change the id of a residue."""
         chain = next(iter(self.struc.get_chains()))
@@ -1373,110 +1393,6 @@ class TransformTests(unittest.TestCase):
             for i in range(0, 3):
                 self.assertAlmostEqual(newpos[i], newpos_check[i])
 
-    def test_Vector(self):
-        """Test Vector object."""
-        v1 = Vector(0, 0, 1)
-        v2 = Vector(0, 0, 0)
-        v3 = Vector(0, 1, 0)
-        v4 = Vector(1, 1, 0)
-
-        self.assertEqual(calc_angle(v1, v2, v3), 1.5707963267948966)
-        self.assertEqual(calc_dihedral(v1, v2, v3, v4), 1.5707963267948966)
-        self.assertTrue(numpy.array_equal((v1 - v2).get_array(), numpy.array([0.0, 0.0, 1.0])))
-        self.assertTrue(numpy.array_equal((v1 - 1).get_array(), numpy.array([-1.0, -1.0, 0.0])))
-        self.assertTrue(numpy.array_equal((v1 - (1, 2, 3)).get_array(), numpy.array([-1.0, -2.0, -2.0])))
-        self.assertTrue(numpy.array_equal((v1 + v2).get_array(), numpy.array([0.0, 0.0, 1.0])))
-        self.assertTrue(numpy.array_equal((v1 + 3).get_array(), numpy.array([3.0, 3.0, 4.0])))
-        self.assertTrue(numpy.array_equal((v1 + (1, 2, 3)).get_array(), numpy.array([1.0, 2.0, 4.0])))
-        self.assertTrue(numpy.array_equal(v1.get_array() / 2, numpy.array([0, 0, 0.5])))
-        self.assertTrue(numpy.array_equal(v1.get_array() / 2, numpy.array([0, 0, 0.5])))
-        self.assertEqual(v1 * v2, 0.0)
-        self.assertTrue(numpy.array_equal((v1 ** v2).get_array(), numpy.array([0.0, -0.0, 0.0])))
-        self.assertTrue(numpy.array_equal((v1 ** 2).get_array(), numpy.array([0.0, 0.0, 2.0])))
-        self.assertTrue(numpy.array_equal((v1 ** (1, 2, 3)).get_array(), numpy.array([0.0, 0.0, 3.0])))
-        self.assertEqual(v1.norm(), 1.0)
-        self.assertEqual(v1.normsq(), 1.0)
-        v1[2] = 10
-        self.assertEqual(v1.__getitem__(2), 10)
-
-        # Vector normalization
-        v1 = Vector([2, 0, 0])
-        self.assertTrue(numpy.array_equal(v1.normalized().get_array(), numpy.array([1, 0, 0])))
-        # State of v1 should not be affected by `normalized`
-        self.assertTrue(numpy.array_equal(v1.get_array(), numpy.array([2, 0, 0])))
-        v1.normalize()
-        # State of v1 should be affected by `normalize`
-        self.assertTrue(numpy.array_equal(v1.get_array(), numpy.array([1, 0, 0])))
-
-    def test_refmat(self):
-        v1 = Vector(0, 0, 1)
-        v2 = Vector(0, 1, 0)
-        ref = refmat(v1, v2)
-        self.assertTrue(numpy.allclose(ref[0], [1.0, 0.0, 0.0]))
-        self.assertTrue(numpy.allclose(ref[1], [0.0, 0.0, 1.0]))
-        self.assertTrue(numpy.allclose(ref[2], [0.0, 1.0, 0.0]))
-        self.assertTrue(numpy.allclose(v1.left_multiply(ref).get_array(), [0.0, 1.0, 0.0]))
-
-    def test_rotmat(self):
-        # Regular 90 deg rotation
-        v1 = Vector(0, 0, 1)
-        v2 = Vector(0, 1, 0)
-        rot = rotmat(v1, v2)
-        self.assertTrue(numpy.allclose(rot[0], numpy.array([1.0, 0.0, 0.0])))
-        self.assertTrue(numpy.allclose(rot[1], numpy.array([0.0, 0.0, 1.0])))
-        self.assertTrue(numpy.allclose(rot[2], numpy.array([0.0, -1.0, 0.0])))
-        self.assertTrue(numpy.allclose(v1.left_multiply(rot).get_array(), [0.0, 1.0, 0.0]))
-        self.assertTrue(numpy.allclose(v1.right_multiply(numpy.transpose(rot)).get_array(), [0.0, 1.0, 0.0]))
-
-        # Applying rotmat works when the rotation is 180 deg (singularity)
-        v1 = Vector([1.0, 0.8, 0])
-        v2 = Vector([-1.0, -0.8, 0])
-        rot = rotmat(v1, v2)
-        v3 = v1.left_multiply(rot)
-        self.assertTrue(numpy.allclose(v2.get_array(), v3.get_array()))
-
-        # Applying rotmat works when the rotation is 0 deg (singularity)
-        v1 = Vector([1.0, 0.8, 0])
-        v2 = Vector([1.0, 0.8, 0])
-        rot = rotmat(v1, v2)
-        v3 = v1.left_multiply(rot)
-        self.assertTrue(numpy.allclose(v1.get_array(), v3.get_array()))
-
-    def test_m2rotaxis(self):
-        # Regular 90 deg rotation
-        v1 = Vector(0, 0, 1)
-        v2 = Vector(0, 1, 0)
-        rot = rotmat(v1, v2)
-        angle, axis = m2rotaxis(rot)
-        self.assertTrue(numpy.allclose(axis.get_array(), [-1.0, 0.0, 0.0]))
-        self.assertTrue(abs(angle - numpy.pi / 2) < 1e-5)
-
-        # 180 deg rotation
-        v1 = Vector([1.0, 0.8, 0])
-        v2 = Vector([-1.0, -0.8, 0])
-        rot = rotmat(v1, v2)
-        angle, axis = m2rotaxis(rot)
-        self.assertTrue(abs(axis * v1) < 1e-5)  # axis orthogonal to v1
-        self.assertTrue(abs(angle - numpy.pi) < 1e-5)
-
-        # 0 deg rotation. Axis must be [1, 0, 0] as per Vector documentation
-        v1 = Vector([1.0, 0.8, 0])
-        v2 = Vector([1.0, 0.8, 0])
-        rot = rotmat(v1, v2)
-        angle, axis = m2rotaxis(rot)
-        self.assertTrue(numpy.allclose(axis.get_array(), [1, 0, 0]))
-        self.assertTrue(abs(angle) < 1e-5)
-
-    def test_Vector_angles(self):
-        angle = random() * numpy.pi
-        axis = Vector(random(3) - random(3))
-        axis.normalize()
-        m = rotaxis(angle, axis)
-        cangle, caxis = m2rotaxis(m)
-        self.assertAlmostEqual(angle, cangle, places=3)
-        self.assertTrue(numpy.allclose(list(map(int, (axis - caxis).get_array())), [0, 0, 0]),
-                        "Want %r and %r to be almost equal" % (axis.get_array(), caxis.get_array()))
-
 
 class PDBParserTests(unittest.TestCase):
     """Test PDBParser module."""
@@ -1526,12 +1442,12 @@ class CopyTests(unittest.TestCase):
 
 
 def eprint(*args, **kwargs):
-    """Helper function that prints to stderr."""
+    """Print to stderr."""
     print(*args, file=sys.stderr, **kwargs)
 
 
 def will_it_float(s):
-    """Helper function that converts the input into a float if it is a number.
+    """Convert the input into a float if it is a number.
 
     If the input is a string, the output does not change.
     """
@@ -1562,7 +1478,7 @@ class DsspTests(unittest.TestCase):
         """Test parsing of DSSP hydrogen bond information."""
         dssp, keys = make_dssp_dict("PDB/2BEG.dssp")
 
-        dssp_indices = set(v[5] for v in dssp.values())
+        dssp_indices = {v[5] for v in dssp.values()}
         hb_indices = set()
 
         # The integers preceding each hydrogen bond energy (kcal/mol) in the
@@ -1572,8 +1488,8 @@ class DsspTests(unittest.TestCase):
         # that actual h-bonds are typically determined by an energetic
         # threshold.
         for val in dssp.values():
-            hb_indices |= set(
-                (val[5] + x) for x in (val[6], val[8], val[10], val[12]))
+            hb_indices |= {
+                val[5] + x for x in (val[6], val[8], val[10], val[12])}
 
         # Check if all h-bond partner indices were successfully parsed.
         self.assertEqual((dssp_indices & hb_indices), hb_indices)
@@ -1598,7 +1514,7 @@ class DsspTests(unittest.TestCase):
                     xtra_list_ref = list(map(will_it_float, xtra_list_ref))
                     # The xtra attribute is a dict.
                     # To compare with the pre-comouted values first sort according to keys:
-                    xtra_itemts = sorted(res.xtra.items(), key=lambda s: s[0])
+                    xtra_itemts = sorted(res.xtra.items(), key=lambda s: s[0])  # noqa: E731
                     # Then extract the list of xtra values for the residue
                     # and convert to floats where possible:
                     xtra_list = [t[1] for t in xtra_itemts]
@@ -1662,14 +1578,15 @@ class NACCESSTests(unittest.TestCase):
 
     See also test_NACCESS_tool.py for run time testing with the tool.
     """
+
     def test_NACCESS_rsa_file(self):
-        """Test parsing of pregenerated rsa NACCESS file"""
+        """Test parsing of pregenerated rsa NACCESS file."""
         with open("PDB/1A8O.rsa") as rsa:
             naccess = process_rsa_data(rsa)
         self.assertEqual(len(naccess), 66)
 
     def test_NACCESS_asa_file(self):
-        """Test parsing of pregenerated asa NACCESS file"""
+        """Test parsing of pregenerated asa NACCESS file."""
         with open("PDB/1A8O.asa") as asa:
             naccess = process_asa_data(asa)
         self.assertEqual(len(naccess), 524)
@@ -1677,8 +1594,9 @@ class NACCESSTests(unittest.TestCase):
 
 class ResidueDepthTests(unittest.TestCase):
     """Tests for ResidueDepth module, except for running MSMS itself."""
+
     def test_pdb_to_xyzr(self):
-        """Test generation of xyzr (atomic radii) file"""
+        """Test generation of xyzr (atomic radii) file."""
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", PDBConstructionWarning)
             p = PDBParser(PERMISSIVE=1)
