@@ -3,27 +3,18 @@
 # license. Please see the LICENSE file that should have been included
 # as part of this package.
 
-"""Unit tests for the PhyloXML and PhyloXMLIO modules.
-"""
+"""Unit tests for the PhyloXML and PhyloXMLIO modules."""
 
 import os
 import tempfile
 import unittest
 from itertools import chain
 
-# Python 2.4 doesn't have ElementTree, which PhyloXMLIO needs
-from Bio import MissingExternalDependencyError
-try:
-    from Bio.Phylo import PhyloXML as PX, PhyloXMLIO
-except ImportError:
-    raise MissingExternalDependencyError(
-            "Install an ElementTree implementation if you want to use "
-            "Bio.Phylo to parse phyloXML files.")
-
 from Bio import Alphabet
 from Bio.Seq import Seq
 from Bio.SeqRecord import SeqRecord
 from Bio.Align import MultipleSeqAlignment
+from Bio.Phylo import PhyloXML as PX, PhyloXMLIO
 
 # Example PhyloXML files
 EX_APAF = 'PhyloXML/apaf.xml'
@@ -47,11 +38,13 @@ def _test_read_factory(source, count):
     phylogenies under the root.
     """
     fname = os.path.basename(source)
+
     def test_read(self):
         phx = PhyloXMLIO.read(source)
         self.assertTrue(phx)
         self.assertEqual(len(phx), count[0])
         self.assertEqual(len(phx.other), count[1])
+
     test_read.__doc__ = "Read %s to produce a phyloXML object." % fname
     return test_read
 
@@ -63,9 +56,11 @@ def _test_parse_factory(source, count):
     function and counts the total number of trees extracted.
     """
     fname = os.path.basename(source)
+
     def test_parse(self):
         trees = PhyloXMLIO.parse(source)
         self.assertEqual(len(list(trees)), count)
+
     test_parse.__doc__ = "Parse the phylogenies in %s." % fname
     return test_parse
 
@@ -77,6 +72,7 @@ def _test_shape_factory(source, shapes):
     clades deep.
     """
     fname = os.path.basename(source)
+
     def test_shape(self):
         trees = PhyloXMLIO.parse(source)
         for tree, shape_expect in zip(trees, shapes):
@@ -85,6 +81,7 @@ def _test_shape_factory(source, shapes):
                 self.assertEqual(len(clade), sub_expect[0])
                 for subclade, len_expect in zip(clade, sub_expect[1]):
                     self.assertEqual(len(subclade), len_expect)
+
     test_shape.__doc__ = "Check the branching structure of %s." % fname
     return test_shape
 
@@ -104,71 +101,69 @@ class ParseTests(unittest.TestCase):
     test_parse_phylo = _test_parse_factory(EX_PHYLO, 13)
     test_parse_dollo = _test_parse_factory(EX_DOLLO, 1)
 
+    # lvl-2 clades, sub-clade counts, lvl-3 clades
     test_shape_apaf = _test_shape_factory(EX_APAF,
-            # lvl-2 clades, sub-clade counts, lvl-3 clades
-                ( ( (2, (2, 2)),
-                    (2, (2, 2)),
-                  ),
-                ),
-            )
+                                          (((2, (2, 2)),
+                                            (2, (2, 2)),
+                                            ),
+                                           ),
+                                          )
     test_shape_bcl2 = _test_shape_factory(EX_BCL2,
-                ( ( (2, (2, 2)),
-                    (2, (2, 2)),
-                  ),
-                ),
-            )
+                                          (((2, (2, 2)),
+                                            (2, (2, 2)),
+                                            ),
+                                           ),
+                                          )
     test_shape_phylo = _test_shape_factory(EX_PHYLO,
-                ( ( (2, (0, 0)),
-                    (0, ()),
-                  ),
-                  ( (2, (0, 0)),
-                    (0, ()),
-                  ),
-                  ( (2, (0, 0)),
-                    (0, ()),
-                  ),
-                  ( (2, (0, 0)),
-                    (0, ()),
-                  ),
-                  ( (2, (0, 0)),
-                    (0, ()),
-                  ),
-                  ( (2, (0, 0)),
-                    (0, ()),
-                  ),
-                  ( (2, (0, 0)),
-                    (0, ()),
-                  ),
-                  ( (2, (0, 0)),
-                    (0, ()),
-                  ),
-                  ( (2, (0, 0)),
-                    (0, ()),
-                  ),
-                  ( (0, ()),
-                    (2, (0, 0)),
-                  ),
-                  ( (3, (0, 0, 0)),
-                    (0, ()),
-                  ),
-                  ( (2, (0, 0)),
-                    (0, ()),
-                  ),
-                  ( (2, (0, 0)),
-                    (0, ()),
-                  ),
-                ),
-            )
+                                           (((2, (0, 0)),
+                                               (0, ()),
+                                             ),
+                                            ((2, (0, 0)),
+                                             (0, ()),
+                                             ),
+                                            ((2, (0, 0)),
+                                             (0, ()),
+                                             ),
+                                            ((2, (0, 0)),
+                                             (0, ()),
+                                             ),
+                                            ((2, (0, 0)),
+                                             (0, ()),
+                                             ),
+                                            ((2, (0, 0)),
+                                             (0, ()),
+                                             ),
+                                            ((2, (0, 0)),
+                                             (0, ()),
+                                             ),
+                                            ((2, (0, 0)),
+                                             (0, ()),
+                                             ),
+                                            ((2, (0, 0)),
+                                             (0, ()),
+                                             ),
+                                            ((0, ()),
+                                             (2, (0, 0)),
+                                             ),
+                                            ((3, (0, 0, 0)),
+                                             (0, ()),
+                                             ),
+                                            ((2, (0, 0)),
+                                             (0, ()),
+                                             ),
+                                            ((2, (0, 0)),
+                                               (0, ()),
+                                             ),
+                                            ),
+                                           )
     test_shape_dollo = _test_shape_factory(EX_DOLLO,
-                ( ( (2, (2, 2)),
-                    (2, (2, 2)),
-                  ),
-                ),
-            )
+                                           (((2, (2, 2)),
+                                             (2, (2, 2)),),),)
 
 
 class TreeTests(unittest.TestCase):
     """Tests for instantiation and attributes of each complex type."""
+
     # ENH: also test check_str() regexps wherever they're used
 
     def test_Phyloxml(self):
@@ -188,9 +183,11 @@ class TreeTests(unittest.TestCase):
         self.assertEqual(otr.tag, 'alignment')
         self.assertEqual(otr.namespace, 'http://example.org/align')
         self.assertEqual(len(otr.children), 3)
-        for child, name, value in zip(otr, ('A', 'B', 'C'), (
-            'acgtcgcggcccgtggaagtcctctcct', 'aggtcgcggcctgtggaagtcctctcct',
-            'taaatcgc--cccgtgg-agtccc-cct')):
+        for child, name, value in zip(otr,
+                                      ('A', 'B', 'C'),
+                                      ('acgtcgcggcccgtggaagtcctctcct',
+                                       'aggtcgcggcctgtggaagtcctctcct',
+                                       'taaatcgc--cccgtgg-agtccc-cct')):
             self.assertEqual(child.tag, 'seq')
             self.assertEqual(child.attributes['name'], name)
             self.assertEqual(child.value, value)
@@ -201,12 +198,11 @@ class TreeTests(unittest.TestCase):
         # Monitor lizards
         self.assertEqual(trees[9].name, 'monitor lizards')
         self.assertEqual(trees[9].description,
-                'a pylogeny of some monitor lizards')
+                         'a pylogeny of some monitor lizards')
         self.assertEqual(trees[9].rooted, True)
         # Network (unrooted)
-        tree6 = trees[6]
         self.assertEqual(trees[6].name,
-                'network, node B is connected to TWO nodes: AB and C')
+                         'network, node B is connected to TWO nodes: AB and C')
         self.assertEqual(trees[6].rooted, False)
 
     def test_Clade(self):
@@ -235,17 +231,18 @@ class TreeTests(unittest.TestCase):
 
     def test_BinaryCharacters(self):
         """Instantiation of BinaryCharacters objects."""
-        tree = PhyloXMLIO.parse(EX_DOLLO).next()
-        bchars = tree.clade[0,0].binary_characters
+        with open(EX_DOLLO) as handle:
+            tree = next(PhyloXMLIO.parse(handle))
+        bchars = tree.clade[0, 0].binary_characters
         self.assertTrue(isinstance(bchars, PX.BinaryCharacters))
         self.assertEqual(bchars.type, 'parsimony inferred')
         for name, count, value in (
-                ('gained',  2, ['Cofilin_ADF', 'Gelsolin']),
-                ('lost',    0, []),
+                ('gained', 2, ['Cofilin_ADF', 'Gelsolin']),
+                ('lost', 0, []),
                 ('present', 2, ['Cofilin_ADF', 'Gelsolin']),
-                ('absent',  None, []),
+                ('absent', None, []),
                 ):
-            self.assertEqual(getattr(bchars, name+'_count'), count)
+            self.assertEqual(getattr(bchars, name + '_count'), count)
             self.assertEqual(getattr(bchars, name), value)
 
     # TODO: BranchColor -- see made_up.xml
@@ -261,18 +258,21 @@ class TreeTests(unittest.TestCase):
 
     def test_Confidence(self):
         """Instantiation of Confidence objects."""
-        tree = PhyloXMLIO.parse(EX_MADE).next()
+        # Because we short circult interation, must close handle explicitly
+        handle = open(EX_MADE)
+        tree = next(PhyloXMLIO.parse(handle))
+        handle.close()
         self.assertEqual(tree.name, 'testing confidence')
         for conf, type, val in zip(tree.confidences,
-                ('bootstrap', 'probability'),
-                (89.0, 0.71)):
+                                   ('bootstrap', 'probability'),
+                                   (89.0, 0.71)):
             self.assertTrue(isinstance(conf, PX.Confidence))
             self.assertEqual(conf.type, type)
             self.assertAlmostEqual(conf.value, val)
         self.assertEqual(tree.clade.name, 'b')
         self.assertAlmostEqual(tree.clade.width, 0.2)
         for conf, val in zip(tree.clade[0].confidences,
-                (0.9, 0.71)):
+                             (0.9, 0.71)):
             self.assertTrue(isinstance(conf, PX.Confidence))
             self.assertEqual(conf.type, 'probability')
             self.assertAlmostEqual(conf.value, val)
@@ -280,8 +280,8 @@ class TreeTests(unittest.TestCase):
     def test_Date(self):
         """Instantiation of Date objects."""
         tree = list(PhyloXMLIO.parse(EX_PHYLO))[11]
-        silurian = tree.clade[0,0].date
-        devonian = tree.clade[0,1].date
+        silurian = tree.clade[0, 0].date
+        devonian = tree.clade[0, 1].date
         ediacaran = tree.clade[1].date
         for date, desc, val in zip(
                 (silurian, devonian, ediacaran),
@@ -300,9 +300,9 @@ class TreeTests(unittest.TestCase):
         Also checks Point type and safe Unicode handling (?).
         """
         tree = list(PhyloXMLIO.parse(EX_PHYLO))[10]
-        hirschweg = tree.clade[0,0].distributions[0]
-        nagoya = tree.clade[0,1].distributions[0]
-        eth_zurich = tree.clade[0,2].distributions[0]
+        hirschweg = tree.clade[0, 0].distributions[0]
+        nagoya = tree.clade[0, 1].distributions[0]
+        eth_zurich = tree.clade[0, 2].distributions[0]
         san_diego = tree.clade[1].distributions[0]
         for dist, desc, lati, longi, alti in zip(
                 (hirschweg, nagoya, eth_zurich, san_diego),
@@ -327,18 +327,28 @@ class TreeTests(unittest.TestCase):
 
         Also checks ProteinDomain type.
         """
-        tree = PhyloXMLIO.parse(EX_APAF).next()
-        clade = tree.clade[0,0,0,0,0,0,0,0,0,0]
+        # Because we short circult interation, must close handle explicitly
+        handle = open(EX_APAF)
+        tree = next(PhyloXMLIO.parse(handle))
+        handle.close()
+        clade = tree.clade[0, 0, 0, 0, 0, 0, 0, 0, 0, 0]
         darch = clade.sequences[0].domain_architecture
         self.assertTrue(isinstance(darch, PX.DomainArchitecture))
         self.assertEqual(darch.length, 1249)
         for domain, start, end, conf, value in zip(darch.domains,
-                (6, 109, 605, 647, 689, 733, 872, 993, 1075, 1117, 1168),
-                (90, 414, 643, 685, 729, 771, 910, 1031, 1113, 1155, 1204),
-                (7.0e-26, 7.2e-117, 2.4e-6, 1.1e-12, 2.4e-7, 4.7e-14, 2.5e-8,
-                    4.6e-6, 6.3e-7, 1.4e-7, 0.3),
-                ('CARD', 'NB-ARC', 'WD40', 'WD40', 'WD40', 'WD40', 'WD40',
-                    'WD40', 'WD40', 'WD40', 'WD40')):
+                                                   (6, 109, 605, 647, 689, 733,
+                                                    872, 993, 1075, 1117, 1168),
+                                                   (90, 414, 643, 685, 729,
+                                                    771, 910, 1031, 1113, 1155,
+                                                    1204),
+                                                   (7.0e-26, 7.2e-117, 2.4e-6,
+                                                    1.1e-12, 2.4e-7, 4.7e-14,
+                                                    2.5e-8, 4.6e-6, 6.3e-7,
+                                                    1.4e-7, 0.3),
+                                                   ('CARD', 'NB-ARC', 'WD40',
+                                                    'WD40', 'WD40', 'WD40',
+                                                    'WD40', 'WD40', 'WD40',
+                                                    'WD40', 'WD40')):
             self.assertTrue(isinstance(domain, PX.ProteinDomain))
             self.assertEqual(domain.start + 1, start)
             self.assertEqual(domain.end, end)
@@ -390,13 +400,17 @@ class TreeTests(unittest.TestCase):
             self.assertEqual(prop.datatype, "xsd:integer")
             self.assertEqual(prop.ref, "NOAA:depth")
             self.assertEqual(prop.applies_to, "node")
-            self.assertEqual(prop.unit, "METRIC:m" )
+            self.assertEqual(prop.unit, "METRIC:m")
             self.assertEqual(prop.value, value)
 
     def test_Reference(self):
         """Instantiation of Reference objects."""
-        tree = PhyloXMLIO.parse(EX_DOLLO).next()
-        reference = tree.clade[0,0,0,0,0,0].references[0]
+        # Because we short circult interation, must close handle explicitly
+        # to avoid a ResourceWarning
+        handle = open(EX_DOLLO)
+        tree = next(PhyloXMLIO.parse(handle))
+        handle.close()
+        reference = tree.clade[0, 0, 0, 0, 0, 0].references[0]
         self.assertTrue(isinstance(reference, PX.Reference))
         self.assertEqual(reference.doi, '10.1038/nature06614')
         self.assertEqual(reference.desc, None)
@@ -417,16 +431,16 @@ class TreeTests(unittest.TestCase):
         self.assertEqual(seq0.name, 'alcohol dehydrogenase')
         self.assertEqual(seq0.annotations[0].ref, 'InterPro:IPR002085')
         # More complete elements
-        seq1 = trees[5].clade[0,0].sequences[0]
-        seq2 = trees[5].clade[0,1].sequences[0]
+        seq1 = trees[5].clade[0, 0].sequences[0]
+        seq2 = trees[5].clade[0, 1].sequences[0]
         seq3 = trees[5].clade[1].sequences[0]
         for seq, sym, acc, name, mol_seq, ann_refs in zip(
                 (seq1, seq2, seq3),
                 ('ADHX', 'RT4I1', 'ADHB'),
                 ('P81431', 'Q54II4', 'Q04945'),
                 ('Alcohol dehydrogenase class-3',
-                 'Reticulon-4-interacting protein 1 homolog, ' \
-                         'mitochondrial precursor',
+                 'Reticulon-4-interacting protein 1 homolog, '
+                 'mitochondrial precursor',
                  'NADH-dependent butanol dehydrogenase B'),
                 ('TDATGKPIKCMAAIAWEAKKPLSIEEVEVAPPKSGEVRIKILHSGVCHTD',
                  'MKGILLNGYGESLDLLEYKTDLPVPKPIKSQVLIKIHSTSINPLDNVMRK',
@@ -463,7 +477,7 @@ class TreeTests(unittest.TestCase):
         """
         trees = list(PhyloXMLIO.parse(EX_PHYLO))
         # Octopus
-        tax5 = trees[5].clade[0,0].taxonomies[0]
+        tax5 = trees[5].clade[0, 0].taxonomies[0]
         self.assertTrue(isinstance(tax5, PX.Taxonomy))
         self.assertEqual(tax5.id.value, '6645')
         self.assertEqual(tax5.id.provider, 'NCBI')
@@ -485,7 +499,7 @@ class TreeTests(unittest.TestCase):
         self.assertTrue(isinstance(uri, PX.Uri))
         self.assertEqual(uri.desc, 'EMBL REPTILE DATABASE')
         self.assertEqual(uri.value,
-                'http://www.embl-heidelberg.de/~uetz/families/Varanidae.html')
+                         'http://www.embl-heidelberg.de/~uetz/families/Varanidae.html')
 
 
 # ---------------------------------------------------------
@@ -493,17 +507,17 @@ class TreeTests(unittest.TestCase):
 
 class WriterTests(unittest.TestCase):
     """Tests for serialization of objects to phyloXML format.
-    
+
     Modifies the globally defined filenames in order to run the other parser
     tests on files (re)generated by PhyloXMLIO's own writer.
     """
 
     def _rewrite_and_call(self, orig_fname, test_cases):
         """Parse, rewrite and retest a phyloXML example file."""
-        infile = open(orig_fname, 'rb')
+        infile = open(orig_fname, 'r')
         phx = PhyloXMLIO.read(infile)
         infile.close()
-        outfile = open(DUMMY, 'w+b')
+        outfile = open(DUMMY, 'w')
         PhyloXMLIO.write(phx, outfile)
         outfile.close()
         for cls, tests in test_cases:
@@ -562,13 +576,13 @@ class WriterTests(unittest.TestCase):
                 (ParseTests, [
                     'test_read_phylo', 'test_parse_phylo', 'test_shape_phylo']),
                 (TreeTests, [
-                    'test_Phyloxml',   'test_Other',
-                    'test_Phylogeny',  'test_Clade',
+                    'test_Phyloxml', 'test_Other',
+                    'test_Phylogeny', 'test_Clade',
                     'test_Annotation', 'test_CladeRelation',
-                    'test_Date',       'test_Distribution',
-                    'test_Events',     'test_Property',
-                    'test_Sequence',   'test_SequenceRelation',
-                    'test_Taxonomy',   'test_Uri',
+                    'test_Date', 'test_Distribution',
+                    'test_Events', 'test_Property',
+                    'test_Sequence', 'test_SequenceRelation',
+                    'test_Taxonomy', 'test_Uri',
                     ]),
                 ))
         finally:
@@ -593,6 +607,7 @@ class WriterTests(unittest.TestCase):
 
 class MethodTests(unittest.TestCase):
     """Tests for methods on specific classes/objects."""
+
     def setUp(self):
         self.phyloxml = PhyloXMLIO.read(EX_PHYLO)
 
@@ -627,11 +642,11 @@ class MethodTests(unittest.TestCase):
             domain_architecture=PX.DomainArchitecture(
                 length=50,
                 domains=[PX.ProteinDomain(*args) for args in (
-                    # value,   start,   end,    confidence
-                    ('FOO',     0,      5,      7.0e-26),
-                    ('BAR',     8,      13,     7.2e-117),
-                    ('A-OK',    21,     34,     2.4e-06),
-                    ('WD40',    40,     50,     0.3))],
+                    # value, start, end, confidence
+                    ('FOO', 0, 5, 7.0e-26),
+                    ('BAR', 8, 13, 7.2e-117),
+                    ('A-OK', 21, 34, 2.4e-06),
+                    ('WD40', 40, 50, 0.3))],
                 ))
         srec = pseq.to_seqrecord()
         # TODO: check seqrec-specific traits (see args)
@@ -647,7 +662,7 @@ class MethodTests(unittest.TestCase):
         # Add sequences to the terminals
         alphabet = Alphabet.Gapped(Alphabet.generic_dna)
         for tip, seqstr in zip(tree.get_terminals(),
-                ('AA--TTA', 'AA--TTG', 'AACCTTC')):
+                               ('AA--TTA', 'AA--TTG', 'AACCTTC')):
             tip.sequences.append(PX.Sequence.from_seqrecord(
                 SeqRecord(Seq(seqstr, alphabet), id=str(tip))))
         # Check the alignment
@@ -661,11 +676,11 @@ class MethodTests(unittest.TestCase):
     def test_clade_getitem(self):
         """Clade.__getitem__: get sub-clades by extended indexing."""
         tree = self.phyloxml.phylogenies[3]
-        self.assertEqual(tree.clade[0,0], tree.clade.clades[0].clades[0])
-        self.assertEqual(tree.clade[0,1], tree.clade.clades[0].clades[1])
+        self.assertEqual(tree.clade[0, 0], tree.clade.clades[0].clades[0])
+        self.assertEqual(tree.clade[0, 1], tree.clade.clades[0].clades[1])
         self.assertEqual(tree.clade[1], tree.clade.clades[1])
         self.assertEqual(len(tree.clade[:]), len(tree.clade.clades))
-        self.assertEqual(len(tree.clade[0,:]),
+        self.assertEqual(len(tree.clade[0, :]),
                          len(tree.clade.clades[0].clades))
 
     def test_phyloxml_getitem(self):
@@ -683,7 +698,7 @@ class MethodTests(unittest.TestCase):
         self.assertEqual('duplications' in evts, False)
         # Attribute access: __get/set/delitem__
         self.assertEqual(evts['speciations'], 1)
-        self.assertRaises(KeyError, lambda k: evts[k], 'duplications')
+        self.assertRaises(KeyError, lambda k: evts[k], 'duplications')  # noqa: E731
         evts['duplications'] = 3
         self.assertEqual(evts.duplications, 3)
         self.assertEqual(len(evts), 2)
@@ -735,6 +750,7 @@ class MethodTests(unittest.TestCase):
 
 # ---------------------------------------------------------
 
+
 if __name__ == '__main__':
     runner = unittest.TextTestRunner(verbosity=2)
     unittest.main(testRunner=runner)
