@@ -3,10 +3,11 @@
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 
-"""Unit test for Astral"""
+"""Unit test for Astral."""
 
 import unittest
-from Bio.SCOP import *
+
+from Bio.SCOP import Astral, Scop
 
 
 class AstralTests(unittest.TestCase):
@@ -24,7 +25,8 @@ class AstralTests(unittest.TestCase):
 
     def testConstructWithCustomFile(self):
         scop = Scop(dir_path="SCOP", version="test")
-        astral = Astral(scop=scop, astral_file="SCOP/scopseq-test/astral-scopdom-seqres-all-test.fa")
+        astral = Astral(scop=scop,
+                        astral_file="SCOP/scopseq-test/astral-scopdom-seqres-all-test.fa")
         self.assertEqual(str(astral.getSeqBySid('d3sdha_')), "AAAAA")
         self.assertEqual(str(astral.getSeqBySid('d4hbib_')), "KKKKK")
 
@@ -52,6 +54,6 @@ class AstralTests(unittest.TestCase):
         # self.assertEqual(d1.isIn(astral.getHashedDomainsClusteredByEv(-15))
 
 
-if __name__=='__main__':
+if __name__ == '__main__':
     runner = unittest.TextTestRunner(verbosity=2)
     unittest.main(testRunner=runner)
