@@ -5,8 +5,7 @@
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 
-
-"""Unit test for Cla"""
+"""Unit test for Cla."""
 
 import unittest
 
@@ -19,19 +18,19 @@ class ClaTests(unittest.TestCase):
         self.filename = './SCOP/dir.cla.scop.txt_test'
 
     def testParse(self):
-        """Test if all records in a CLA file are being read"""
-        f=open(self.filename)
+        """Test if all records in a CLA file are being read."""
+        f = open(self.filename)
         try:
             count = 0
             records = Cla.parse(f)
             for record in records:
-                count +=1
+                count += 1
             self.assertEqual(count, 14)
         finally:
             f.close()
 
     def testStr(self):
-        """Test if we can convert each record to a string correctly"""
+        """Test if we can convert each record to a string correctly."""
         f = open(self.filename)
         try:
             for line in f:
@@ -49,19 +48,19 @@ class ClaTests(unittest.TestCase):
                 actual_hierarchy = dict(pair.split('=') for pair
                                         in actual_hierarchy)
                 self.assertEqual(len(actual_hierarchy),
-                                  len(expected_hierarchy))
+                                 len(expected_hierarchy))
                 for key, actual_value in actual_hierarchy.items():
                     self.assertEqual(actual_value, expected_hierarchy[key])
         finally:
             f.close()
 
     def testError(self):
-        """Test if a corrupt record raises the appropriate exception"""
+        """Test if a corrupt record raises the appropriate exception."""
         corruptRec = "49268\tsp\tb.1.2.1\t-\n"
         self.assertRaises(ValueError, Cla.Record, corruptRec)
 
     def testRecord(self):
-        """Test one record in detail"""
+        """Test one record in detail."""
         recLine = 'd1dan.1\t1dan\tT:,U:91-106\tb.1.2.1\t21953\tcl=48724,cf=48725,sf=49265,fa=49266,dm=49267,sp=49268,px=21953'
 
         record = Cla.Record(recLine)
@@ -79,16 +78,16 @@ class ClaTests(unittest.TestCase):
                                             'px': 21953})
 
     def testIndex(self):
-        """Test CLA file indexing"""
+        """Test CLA file indexing."""
         index = Cla.Index(self.filename)
 
         self.assertEqual(len(index), 14)
-        self.assertTrue('d4hbia_' in index)
+        self.assertIn('d4hbia_', index)
 
         rec = index['d1hbia_']
         self.assertEqual(rec.sunid, 14996)
 
 
-if __name__=='__main__':
+if __name__ == '__main__':
     runner = unittest.TextTestRunner(verbosity=2)
     unittest.main(testRunner=runner)
