@@ -17,14 +17,15 @@ FMT = 'blast-tab'
 
 
 def get_file(filename):
-    """Returns the path of a test file."""
+    """Return the path of a test file."""
     return os.path.join(TEST_DIR, filename)
 
 
 class BlastTabCases(unittest.TestCase):
+    """Tests for the tab-separated BLAST parser."""
 
     def test_tab_2228_tblastn_001(self):
-        "Test parsing TBLASTN 2.2.28+ tabular output (tab_2228_tblastn_001)"
+        """Test parsing TBLASTN 2.2.28+ tabular output (tab_2228_tblastn_001)."""
         tab_file = get_file('tab_2228_tblastn_001.txt')
         qresults = list(parse(tab_file, FMT,
                               fields=['evalue', 'sallseqid', 'qseqid'],
@@ -34,14 +35,14 @@ class BlastTabCases(unittest.TestCase):
         self.assertEqual(10, len(qresults[0].hits))
         # there is one hit with an alternative ID
         self.assertEqual(qresults[0]['gi|148227873|ref|NM_001095167.1|'],
-                qresults[0]['gi|55250552|gb|BC086280.1|'])
+                         qresults[0]['gi|55250552|gb|BC086280.1|'])
 
         # check some of the HSPs
         self.assertEqual(0.0, qresults[0][0][0].evalue)
         self.assertEqual(8e-173, qresults[0][-1][0].evalue)
 
     def test_tab_2228_tblastx_001(self):
-        "Test parsing TBLASTX 2.2.28+ tabular output (tab_2228_tblastx_001)"
+        """Test parsing TBLASTX 2.2.28+ tabular output (tab_2228_tblastx_001)."""
         tab_file = get_file('tab_2228_tblastx_001.txt')
         qresults = list(parse(tab_file, FMT,
                               fields=list(all_fields.values()),
@@ -50,10 +51,10 @@ class BlastTabCases(unittest.TestCase):
         # this a single query, with 192 hits and 243 hsps
         self.assertEqual(1, len(qresults))
         self.assertEqual(192, len(qresults[0].hits))
-        self.assertEqual(243, sum([len(x) for x in qresults[0]]))
+        self.assertEqual(243, sum(len(x) for x in qresults[0]))
         # there is one hit with an alternative ID
         self.assertEqual(qresults[0]['gi|31126987|gb|AY255526.2|'],
-                qresults[0]['gi|31342050|ref|NM_181083.2|'])
+                         qresults[0]['gi|31342050|ref|NM_181083.2|'])
 
         # only checking the new fields in 2.2.28+
         hit = qresults[0][0]
@@ -65,8 +66,8 @@ class BlastTabCases(unittest.TestCase):
         self.assertEqual(['N/A'], hit.super_kingdoms)
         self.assertEqual('Saccharomyces cerevisiae S288c Mon2p (MON2), mRNA', hit.title)
         self.assertEqual(['Saccharomyces cerevisiae S288c Mon2p (MON2), mRNA',
-            'Synthetic construct Saccharomyces cerevisiae clone '
-            'FLH203015.01X MON2, complete sequence'], hit.title_all)
+                         'Synthetic construct Saccharomyces cerevisiae clone '
+                          'FLH203015.01X MON2, complete sequence'], hit.title_all)
         self.assertEqual('N/A', hit.strand)
         self.assertEqual(100.0, hit.query_coverage)
 
@@ -78,8 +79,7 @@ class BlastTabCases(unittest.TestCase):
         self.assertEqual(12.0, hit[6].query_coverage)
 
     def test_tab_2226_tblastn_001(self):
-        "Test parsing TBLASTN 2.2.26+ tabular output (tab_2226_tblastn_001)"
-
+        """Test parsing TBLASTN 2.2.26+ tabular output (tab_2226_tblastn_001)."""
         xml_file = get_file('tab_2226_tblastn_001.txt')
         qresults = parse(xml_file, FMT)
         counter = 0
@@ -174,8 +174,7 @@ class BlastTabCases(unittest.TestCase):
         self.assertEqual(2, counter)
 
     def test_tab_2226_tblastn_002(self):
-        "Test parsing TBLASTN 2.2.26+ tabular output (tab_2226_tblastn_002)"
-
+        """Test parsing TBLASTN 2.2.26+ tabular output (tab_2226_tblastn_002)."""
         xml_file = get_file('tab_2226_tblastn_002.txt')
         qresults = parse(xml_file, FMT)
 
@@ -183,8 +182,7 @@ class BlastTabCases(unittest.TestCase):
         self.assertRaises(StopIteration, next, qresults)
 
     def test_tab_2226_tblastn_003(self):
-        "Test parsing TBLASTN 2.2.26+ tabular output (tab_2226_tblastn_003)"
-
+        """Test parsing TBLASTN 2.2.26+ tabular output (tab_2226_tblastn_003)."""
         xml_file = get_file('tab_2226_tblastn_003.txt')
         qresults = parse(xml_file, FMT)
         counter = 0
@@ -239,8 +237,7 @@ class BlastTabCases(unittest.TestCase):
         self.assertEqual(1, counter)
 
     def test_tab_2226_tblastn_004(self):
-        "Test parsing TBLASTN 2.2.26+ tabular output (tab_2226_tblastn_004)"
-
+        """Test parsing TBLASTN 2.2.26+ tabular output (tab_2226_tblastn_004)."""
         xml_file = get_file('tab_2226_tblastn_004.txt')
         qresults = parse(xml_file, FMT)
         counter = 0
@@ -289,8 +286,7 @@ class BlastTabCases(unittest.TestCase):
         self.assertEqual(1, counter)
 
     def test_tab_2226_tblastn_005(self):
-        "Test parsing TBLASTN 2.2.26+ tabular output with comments (tab_2226_tblastn_005)"
-
+        """Test parsing TBLASTN 2.2.26+ tabular output with comments (tab_2226_tblastn_005)."""
         xml_file = get_file('tab_2226_tblastn_005.txt')
         qresults = parse(xml_file, FMT, comments=True)
         counter = 0
@@ -401,8 +397,7 @@ class BlastTabCases(unittest.TestCase):
         self.assertEqual(3, counter)
 
     def test_tab_2226_tblastn_005_comments_false(self):
-        "Test parsing TBLASTN 2.2.26+ tabular output with comments (tab_2226_tblastn_005)"
-
+        """Test parsing TBLASTN 2.2.26+ tabular output with comments (tab_2226_tblastn_005)."""
         tab_file = get_file('tab_2226_tblastn_005.txt')
         exc_msg = ("Encountered unexpected character '#' at the beginning of"
                    " a line. Set comments=True if the file is a commented"
@@ -412,8 +407,7 @@ class BlastTabCases(unittest.TestCase):
             next(qresults)
 
     def test_tab_2226_tblastn_006(self):
-        "Test parsing TBLASTN 2.2.26+ tabular output with comments (tab_2226_tblastn_006)"
-
+        """Test parsing TBLASTN 2.2.26+ tabular output with comments (tab_2226_tblastn_006)."""
         xml_file = get_file('tab_2226_tblastn_006.txt')
         qresults = parse(xml_file, FMT, comments=True)
         counter = 0
@@ -432,8 +426,7 @@ class BlastTabCases(unittest.TestCase):
         self.assertEqual(1, counter)
 
     def test_tab_2226_tblastn_007(self):
-        "Test parsing TBLASTN 2.2.26+ tabular output with comments (tab_2226_tblastn_007)"
-
+        """Test parsing TBLASTN 2.2.26+ tabular output with comments (tab_2226_tblastn_007)."""
         xml_file = get_file('tab_2226_tblastn_007.txt')
         qresults = parse(xml_file, FMT, comments=True)
         counter = 0
@@ -490,8 +483,7 @@ class BlastTabCases(unittest.TestCase):
         self.assertEqual(1, counter)
 
     def test_tab_2226_tblastn_008(self):
-        "Test parsing TBLASTN 2.2.26+ tabular output with comments (tab_2226_tblastn_008)"
-
+        """Test parsing TBLASTN 2.2.26+ tabular output with comments (tab_2226_tblastn_008)."""
         xml_file = get_file('tab_2226_tblastn_008.txt')
         qresults = parse(xml_file, FMT, comments=True)
         counter = 0
@@ -543,8 +535,7 @@ class BlastTabCases(unittest.TestCase):
         self.assertEqual(1, counter)
 
     def test_tab_2226_tblastn_009(self):
-        "Test parsing TBLASTN 2.2.26+ tabular output (tab_2226_tblastn_009)"
-
+        """Test parsing TBLASTN 2.2.26+ tabular output (tab_2226_tblastn_009)."""
         xml_file = get_file('tab_2226_tblastn_009.txt')
         qresults = parse(xml_file, FMT, fields=('qseqid', 'sseqid'))
         counter = 0
@@ -605,8 +596,7 @@ class BlastTabCases(unittest.TestCase):
         self.assertEqual(2, counter)
 
     def test_tab_2226_tblastn_010(self):
-        "Test parsing TBLASTN 2.2.26+ tabular output with comments (tab_2226_tblastn_010)"
-
+        """Test parsing TBLASTN 2.2.26+ tabular output with comments (tab_2226_tblastn_010)."""
         xml_file = get_file('tab_2226_tblastn_010.txt')
         qresults = parse(xml_file, FMT, comments=True)
         counter = 0
@@ -685,8 +675,7 @@ class BlastTabCases(unittest.TestCase):
         self.assertEqual(3, counter)
 
     def test_tab_2226_tblastn_011(self):
-        "Test parsing TBLASTN 2.2.26+ tabular output with comments (tab_2226_tblastn_011)"
-
+        """Test parsing TBLASTN 2.2.26+ tabular output with comments (tab_2226_tblastn_011)."""
         xml_file = get_file('tab_2226_tblastn_011.txt')
         qresults = parse(xml_file, FMT, comments=True)
         counter = 0
@@ -855,8 +844,7 @@ class BlastTabCases(unittest.TestCase):
         self.assertEqual(3, counter)
 
     def test_tab_2226_tblastn_012(self):
-        "Test parsing TBLASTN 2.2.26+ tabular output with comments (tab_2226_tblastn_012)"
-
+        """Test parsing TBLASTN 2.2.26+ tabular output with comments (tab_2226_tblastn_012)."""
         xml_file = get_file('tab_2226_tblastn_012.txt')
         qresults = parse(xml_file, FMT, comments=True)
         counter = 0
@@ -899,8 +887,7 @@ class BlastTabCases(unittest.TestCase):
         self.assertEqual(3, counter)
 
     def test_tab_2226_tblastn_013(self):
-        "Test parsing TBLASTN 2.2.26+ tabular output (tab_2226_tblastn_013)"
-
+        """Test parsing TBLASTN 2.2.26+ tabular output (tab_2226_tblastn_013)."""
         xml_file = get_file('tab_2226_tblastn_013.txt')
         qresults = parse(xml_file, FMT, fields="qseq std sseq")
         counter = 0
