@@ -4,6 +4,8 @@
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 
+"""Tests for SearchIO hmmer2 text module."""
+
 import unittest
 from os import path
 
@@ -15,7 +17,7 @@ class HmmpfamTests(unittest.TestCase):
     fmt = 'hmmer2-text'
 
     def test_hmmpfam_21(self):
-        """Test parsing hmmpfam 2.1 file (text_21_hmmpfam_001.out)"""
+        """Test parsing hmmpfam 2.1 file (text_21_hmmpfam_001.out)."""
         results = parse(path.join("Hmmer", "text_21_hmmpfam_001.out"), self.fmt)
         res = next(results)
         self.assertEqual('roa1_drome', res.id)
@@ -68,7 +70,7 @@ class HmmpfamTests(unittest.TestCase):
                          str(hsp.query.seq))
 
     def test_hmmpfam_22(self):
-        """Test parsing hmmpfam 2.2 file (text_22_hmmpfam_001.out)"""
+        """Test parsing hmmpfam 2.2 file (text_22_hmmpfam_001.out)."""
         results = parse(path.join("Hmmer", "text_22_hmmpfam_001.out"), self.fmt)
         res = next(results)
         self.assertEqual('gi|1522636|gb|AAC37060.1|', res.id)
@@ -105,7 +107,7 @@ class HmmpfamTests(unittest.TestCase):
                          str(hsp.query.seq))
 
     def test_hmmpfam_23(self):
-        """Test parsing hmmpfam 2.3 file (text_23_hmmpfam_001.out)"""
+        """Test parsing hmmpfam 2.3 file (text_23_hmmpfam_001.out)."""
         results = parse(path.join("Hmmer", "text_23_hmmpfam_001.out"), self.fmt)
         res = next(results)
         self.assertEqual('gi|90819130|dbj|BAE92499.1|', res.id)
@@ -153,7 +155,7 @@ class HmmpfamTests(unittest.TestCase):
         self.assertAlmostEqual(9e-255, hsp.evalue)
 
     def test_hmmpfam_23_no_match(self):
-        """Test parsing hmmpfam 2.3 file (text_23_hmmpfam_002.out)"""
+        """Test parsing hmmpfam 2.3 file (text_23_hmmpfam_002.out)."""
         results = parse(path.join("Hmmer", "text_23_hmmpfam_002.out"), self.fmt)
         res = next(results)
 
@@ -166,7 +168,7 @@ class HmmpfamTests(unittest.TestCase):
         self.assertEqual(0, len(res.hits))
 
     def test_hmmpfam_23_missing_consensus(self):
-        """Test parsing hmmpfam 2.3 file (text_23_hmmpfam_003.out)"""
+        """Test parsing hmmpfam 2.3 file (text_23_hmmpfam_003.out)."""
         results = parse(path.join("Hmmer", "text_23_hmmpfam_003.out"), self.fmt)
         res = next(results)
 
@@ -216,7 +218,7 @@ class HmmpfamTests(unittest.TestCase):
         self.assertEqual('PKSI-FK', res[1].id)
 
     def test_hmmpfam_24(self):
-        """Test parsing hmmpfam 2.4 file (text_24_hmmpfam_001.out)"""
+        """Test parsing hmmpfam 2.4 file (text_24_hmmpfam_001.out)."""
         results = list(parse(path.join("Hmmer", "text_24_hmmpfam_001.out"), self.fmt))
         self.assertEqual(5, len(results))
 
@@ -258,20 +260,20 @@ class HmmpfamTests(unittest.TestCase):
         self.assertEqual(271, hsp.query_end)
         self.assertEqual('..', hsp.query_endtype)
         self.assertEqual('ENHIKDALSRIVVEMIKREWPQHWPDMLIELDTLSKQG--',
-                str(hsp.query.seq)[:40])
+                         str(hsp.query.seq)[:40])
         self.assertEqual('+++++  L+++++e++k+ewP++Wp+ + +l  l++++  ',
-                str(hsp.aln_annotation['similarity'])[:40])
+                         str(hsp.aln_annotation['similarity'])[:40])
         self.assertEqual('WVSMSHITA-ENCkLLEILCLLL----NEQELQLGAAECL',
-                str(hsp.query.seq)[-40:])
+                         str(hsp.query.seq)[-40:])
         self.assertEqual(0, hsp.hit_start)
         self.assertEqual(178, hsp.hit_end)
         self.assertEqual('[]', hsp.hit_endtype)
         self.assertEqual('pkflrnKLalalaelakqewPsnWpsffpdlvsllsssss',
-                str(hsp.hit.seq)[:40])
+                         str(hsp.hit.seq)[:40])
         self.assertEqual('W+++++i + ++++ll++l+ lL    +  +l++ A+eCL',
-                str(hsp.aln_annotation['similarity'])[-40:])
+                         str(hsp.aln_annotation['similarity'])[-40:])
         self.assertEqual('Wipiglianvnpi.llnllfslLsgpesdpdlreaAveCL',
-                str(hsp.hit.seq)[-40:])
+                         str(hsp.hit.seq)[-40:])
 
         # fourth qresult, second from last hit
         hit = res[-2]
@@ -316,7 +318,7 @@ class HmmsearchTests(unittest.TestCase):
     fmt = 'hmmer2-text'
 
     def test_hmmsearch_20(self):
-        """Test parsing hmmsearch 2.0 file (text_20_hmmsearch_001.out)"""
+        """Test parsing hmmsearch 2.0 file (text_20_hmmsearch_001.out)."""
         res = read(path.join("Hmmer", "text_20_hmmsearch_001.out"), self.fmt)
 
         # first query
@@ -394,7 +396,7 @@ class HmmsearchTests(unittest.TestCase):
         self.assertEqual('..', hsp.hit_endtype)
 
     def test_hmmsearch_22(self):
-        """Test parsing hmmsearch 2.2 file (text_22_hmmsearch_001.out)"""
+        """Test parsing hmmsearch 2.2 file (text_22_hmmsearch_001.out)."""
         res = read(path.join("Hmmer", "text_22_hmmsearch_001.out"), self.fmt)
 
         # first query
@@ -430,9 +432,9 @@ class HmmsearchTests(unittest.TestCase):
         self.assertEqual('IVKNSWGtdWGEnGYfriaRgknksgkneCGIaseasypi', str(hsp.query.seq)[-40:])
         self.assertEqual(337, len(hsp.query.seq))
         self.assertEqual('+P+++DWRe kg  VtpVK+QG qCGSCWAFSa g lEg+',
-                str(hsp.aln_annotation['similarity'])[:40])
+                         str(hsp.aln_annotation['similarity'])[:40])
         self.assertEqual('+VKNSWG++WG++GY++ia+++n    n+CG+a+ asypi',
-                str(hsp.aln_annotation['similarity'])[-40:])
+                         str(hsp.aln_annotation['similarity'])[-40:])
         self.assertEqual(113, hsp.hit_start)
         self.assertEqual(332, hsp.hit_end)
         self.assertEqual('..', hsp.hit_endtype)
@@ -465,9 +467,9 @@ class HmmsearchTests(unittest.TestCase):
         self.assertEqual('IVKNSWGtdWGEnGYfriaRgknksgkneCGIaseasypi', str(hsp.query.seq)[-40:])
         self.assertEqual(337, len(hsp.query.seq))
         self.assertEqual('+Pe +DWR+ kg aVtpVK+QG +CGSCWAFSav ++Eg+',
-                str(hsp.aln_annotation['similarity'])[:40])
+                         str(hsp.aln_annotation['similarity'])[:40])
         self.assertEqual('++KNSWGt WGEnGY+ri+Rg+++s ++ CG+ ++  yp+',
-                str(hsp.aln_annotation['similarity'])[-40:])
+                         str(hsp.aln_annotation['similarity'])[-40:])
         self.assertEqual(133, hsp.hit_start)
         self.assertEqual(343, hsp.hit_end)
         self.assertEqual('..', hsp.hit_endtype)
