@@ -15,7 +15,7 @@ class Hmmer3TextRawCases(CheckRaw):
     fmt = 'hmmer3-text'
 
     def test_hmmer3text_30_multiple_first(self):
-        """Test hmmer3-text raw string retrieval, HMMER 3.0, multiple queries, first (text_30_hmmscan_001.out)"""
+        """Test hmmer3-text raw string retrieval, HMMER 3.0, multiple queries, first (text_30_hmmscan_001.out)."""
         filename = 'Hmmer/text_30_hmmscan_001.out'
         raw = """# hmmscan :: search sequence(s) against a profile database
 # HMMER 3.0 (March 2010); http://hmmer.org/
@@ -60,7 +60,7 @@ Domain search space  (domZ):               0  [number of targets reported over t
         self.check_raw(filename, "random_s00", raw)
 
     def test_hmmer3text_30_multiple_middle(self):
-        """Test hmmer3-text raw string retrieval, HMMER 3.0, multiple queries, middle (text_30_hmmscan_001.out)"""
+        """Test hmmer3-text raw string retrieval, HMMER 3.0, multiple queries, middle (text_30_hmmscan_001.out)."""
         filename = 'Hmmer/text_30_hmmscan_001.out'
         raw = """# hmmscan :: search sequence(s) against a profile database
 # HMMER 3.0 (March 2010); http://hmmer.org/
@@ -118,11 +118,11 @@ Domain search space  (domZ):               1  [number of targets reported over t
 # CPU time: 0.33u 0.16s 00:00:00.49 Elapsed: 00:00:00.21
 # Mc/sec: 1757.33
 //
-"""
+"""  # noqa : W291
         self.check_raw(filename, "gi|4885477|ref|NP_005359.1|", raw)
 
     def test_hmmer3text_30_multiple_last(self):
-        """Test hmmer3-text raw string retrieval, HMMER 3.0, multiple queries, last (text_30_hmmscan_001.out)"""
+        """Test hmmer3-text raw string retrieval, HMMER 3.0, multiple queries, last (text_30_hmmscan_001.out)."""
         filename = 'Hmmer/text_30_hmmscan_001.out'
         raw = """# hmmscan :: search sequence(s) against a profile database
 # HMMER 3.0 (March 2010); http://hmmer.org/
@@ -234,11 +234,11 @@ Domain search space  (domZ):               5  [number of targets reported over t
 # CPU time: 0.51u 0.15s 00:00:00.66 Elapsed: 00:00:00.23
 # Mc/sec: 3667.47
 //
-"""
+"""  # noqa : W291
         self.check_raw(filename, "gi|125490392|ref|NP_038661.2|", raw)
 
     def test_hmmer3text_30_single(self):
-        """Test hmmer3-text raw string retrieval, HMMER 3.0, single query (text_30_hmmscan_003.out)"""
+        """Test hmmer3-text raw string retrieval, HMMER 3.0, single query (text_30_hmmscan_003.out)."""
         filename = 'Hmmer/text_30_hmmscan_003.out'
         raw = """# hmmscan :: search sequence(s) against a profile database
 # HMMER 3.0 (March 2010); http://hmmer.org/
@@ -296,7 +296,7 @@ Domain search space  (domZ):               1  [number of targets reported over t
 # CPU time: 0.28u 0.17s 00:00:00.45 Elapsed: 00:00:00.21
 # Mc/sec: 1757.33
 //
-"""
+"""  # noqa : W291
         self.check_raw(filename, "gi|4885477|ref|NP_005359.1|", raw)
 
 
@@ -305,36 +305,36 @@ class Hmmer3TextIndexCases(CheckIndex):
     fmt = 'hmmer3-text'
 
     def test_hmmertext_text_30_hmmscan_001(self):
-        """Test hmmer3-text indexing, HMMER 3.0, multiple queries"""
+        """Test hmmer3-text indexing, HMMER 3.0, multiple queries."""
         filename = 'Hmmer/text_30_hmmscan_001.out'
         self.check_index(filename, self.fmt)
 
     def test_hmmertext_text_30_hmmscan_002(self):
-        """Test hmmer3-text indexing, HMMER 3.0, single query, no hits"""
+        """Test hmmer3-text indexing, HMMER 3.0, single query, no hits."""
         filename = 'Hmmer/text_30_hmmscan_002.out'
         self.check_index(filename, self.fmt)
 
     def test_hmmertext_text_30_hmmscan_006(self):
-        """Test hmmer3-text indexing, HMMER 3.0, single query, multiple hits"""
+        """Test hmmer3-text indexing, HMMER 3.0, single query, multiple hits."""
         filename = 'Hmmer/text_30_hmmscan_006.out'
         self.check_index(filename, self.fmt)
 
     def test_hmmertext_text_30_hmmscan_007(self):
-        """Test hmmer3-text indexing, HMMER 3.0, single query, no alignments"""
+        """Test hmmer3-text indexing, HMMER 3.0, single query, no alignments."""
         filename = 'Hmmer/text_30_hmmscan_007.out'
         self.check_index(filename, self.fmt)
 
     def test_hmmertext_text_30_hmmscan_008(self):
-        """Test hmmer3-text indexing, HMMER 3.0, single query, no alignment width"""
+        """Test hmmer3-text indexing, HMMER 3.0, single query, no alignment width."""
         filename = 'Hmmer/text_30_hmmscan_008.out'
         self.check_index(filename, self.fmt)
 
     def test_hmmertext_text_30_hmmsearch_005(self):
-        """Test hmmer3-text indexing, HMMER 3.0, multiple queries"""
+        """Test hmmer3-text indexing, HMMER 3.0, multiple queries."""
         filename = 'Hmmer/text_30_hmmsearch_005.out'
         self.check_index(filename, self.fmt)
 
 
 if __name__ == "__main__":
-    runner = unittest.TextTestRunner(verbosity = 2)
+    runner = unittest.TextTestRunner(verbosity=2)
     unittest.main(testRunner=runner)
