@@ -1,3 +1,7 @@
+# This code is part of the Biopython distribution and governed by its
+# license.  Please see the LICENSE file that should have been included
+# as part of this package.
+
 """Tests for SearchIO InterproscanIO parsers."""
 
 import os
@@ -15,7 +19,7 @@ FMT = 'interproscan-xml'
 
 
 def get_file(filename):
-    """Returns the path of a test file."""
+    """Return the path of a test file."""
     return os.path.join(TEST_DIR, filename)
 
 
@@ -35,7 +39,7 @@ class InterproscanXmlCases(unittest.TestCase):
         # test parsed values of qresult
         self.assertEqual('AT5G23090.4', qresult.id)
         self.assertEqual('pacid=19665592 transcript=AT5G23090.4 locus=AT5G23090 ID=AT5G23090.4.TAIR10 annot-version=TAIR10',
-                qresult.description)
+                         qresult.description)
         self.assertEqual(4, len(qresult))
 
         hit = qresult[0]
